# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SendNotification(BaseModel):
    send_notification: Optional["SendNotificationSendNotification"] = Field(
        alias="sendNotification"
    )


class SendNotificationSendNotification(BaseModel):
    result: Optional[bool]


SendNotification.model_rebuild()
