# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountEmotions(BaseModel):
    count_emotions: Optional["CountEmotionsCountEmotions"] = Field(
        alias="countEmotions"
    )


class CountEmotionsCountEmotions(BaseModel):
    count: Optional[Any]


CountEmotions.model_rebuild()
