# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class RemoveSkillsFromCollection(BaseModel):
    remove_skills_from_collection: Optional[
        "RemoveSkillsFromCollectionRemoveSkillsFromCollection"
    ] = Field(alias="removeSkillsFromCollection")


class RemoveSkillsFromCollectionRemoveSkillsFromCollection(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[Optional["RemoveSkillsFromCollectionRemoveSkillsFromCollectionContents"]]
    ]


class RemoveSkillsFromCollectionRemoveSkillsFromCollectionContents(BaseModel):
    id: str
    name: str


RemoveSkillsFromCollection.model_rebuild()
RemoveSkillsFromCollectionRemoveSkillsFromCollection.model_rebuild()
