# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class UpdatePersona(BaseModel):
    update_persona: Optional["UpdatePersonaUpdatePersona"] = Field(
        alias="updatePersona"
    )


class UpdatePersonaUpdatePersona(BaseModel):
    id: str
    name: str
    state: EntityState
    identifier: Optional[str]
    platform: Optional[str]
    display_name: Optional[str] = Field(alias="displayName")
    timezone: Optional[str]
    role: Optional[str]


UpdatePersona.model_rebuild()
