# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalTherapies(BaseModel):
    count_medical_therapies: Optional["CountMedicalTherapiesCountMedicalTherapies"] = (
        Field(alias="countMedicalTherapies")
    )


class CountMedicalTherapiesCountMedicalTherapies(BaseModel):
    count: Optional[Any]


CountMedicalTherapies.model_rebuild()
