# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DisableSkill(BaseModel):
    disable_skill: Optional["DisableSkillDisableSkill"] = Field(alias="disableSkill")


class DisableSkillDisableSkill(BaseModel):
    id: str
    state: EntityState


DisableSkill.model_rebuild()
