# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountSkills(BaseModel):
    count_skills: Optional["CountSkillsCountSkills"] = Field(alias="countSkills")


class CountSkillsCountSkills(BaseModel):
    count: Optional[Any]


CountSkills.model_rebuild()
