# Generated by ariadne-codegen
# Source: https://data-scus.graphlit.io/api/v1/graphql

from enum import Enum


class FactCategory(str, Enum):
    RELATIONSHIP = "RELATIONSHIP"
    EVENT = "EVENT"
    FACT = "FACT"
    PREFERENCE = "PREFERENCE"
    CHANGE = "CHANGE"
    QUANTITATIVE = "QUANTITATIVE"
    GOAL = "GOAL"
    CAPABILITY = "CAPABILITY"
    CONSTRAINT = "CONSTRAINT"
    DECISION = "DECISION"
    APPROVAL = "APPROVAL"
    EXCEPTION = "EXCEPTION"
    ESCALATION = "ESCALATION"
    OVERRIDE = "OVERRIDE"
    PRECEDENT = "PRECEDENT"
    RATIONALE = "RATIONALE"
    COMMITMENT = "COMMITMENT"
    DELEGATION = "DELEGATION"


class TwitterAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class AzureOpenAIModels(str, Enum):
    GPT35_TURBO_16K = "GPT35_TURBO_16K"
    GPT4 = "GPT4"
    GPT4_TURBO_128K = "GPT4_TURBO_128K"
    CUSTOM = "CUSTOM"


class TwelveLabsModels(str, Enum):
    MARENGO_3_0 = "MARENGO_3_0"


class LinkTypes(str, Enum):
    DROPBOX = "DROPBOX"
    TYPE_FORM = "TYPE_FORM"
    AIRTABLE = "AIRTABLE"
    MICROSOFT_TEAMS = "MICROSOFT_TEAMS"
    DISCORD = "DISCORD"
    APPLE = "APPLE"
    SLACK = "SLACK"
    ANGEL_LIST = "ANGEL_LIST"
    CRUNCHBASE = "CRUNCHBASE"
    LINKED_IN = "LINKED_IN"
    DIFFBOT = "DIFFBOT"
    REDDIT = "REDDIT"
    GOOGLE = "GOOGLE"
    IFTTT = "IFTTT"
    FACEBOOK = "FACEBOOK"
    WIKIPEDIA = "WIKIPEDIA"
    WIKIMEDIA = "WIKIMEDIA"
    WIKIDATA = "WIKIDATA"
    INSTAGRAM = "INSTAGRAM"
    TWITCH = "TWITCH"
    POCKET_CASTS = "POCKET_CASTS"
    SPOTIFY = "SPOTIFY"
    TUNE_IN = "TUNE_IN"
    STITCHER = "STITCHER"
    ANCHOR_FM = "ANCHOR_FM"
    TRANSISTOR_FM = "TRANSISTOR_FM"
    I_TUNES = "I_TUNES"
    PANDORA = "PANDORA"
    SOUND_CLOUD = "SOUND_CLOUD"
    BANDCAMP = "BANDCAMP"
    TIK_TOK = "TIK_TOK"
    YOU_TUBE = "YOU_TUBE"
    TWITTER = "TWITTER"
    X = "X"
    MEDIUM = "MEDIUM"
    NOTION = "NOTION"
    HUB_SPOT = "HUB_SPOT"
    LINEAR = "LINEAR"
    GIT_HUB = "GIT_HUB"
    GIT_HUB_PAGES = "GIT_HUB_PAGES"
    RSS = "RSS"
    EMAIL = "EMAIL"
    MEDIA = "MEDIA"
    WEB = "WEB"
    FILE = "FILE"


class CollectionTypes(str, Enum):
    COLLECTION = "COLLECTION"
    CONVERSATION = "CONVERSATION"
    THREAD = "THREAD"
    SERIES = "SERIES"
    FOLDER = "FOLDER"


class MedicalProcedureFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class SlackAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class FeedTypes(str, Enum):
    INTERCOM = "INTERCOM"
    ZENDESK = "ZENDESK"
    NOTION = "NOTION"
    TWITTER = "TWITTER"
    SLACK = "SLACK"
    MICROSOFT_TEAMS = "MICROSOFT_TEAMS"
    DISCORD = "DISCORD"
    REDDIT = "REDDIT"
    LINKED_IN = "LINKED_IN"
    WEB = "WEB"
    RSS = "RSS"
    SITE = "SITE"
    YOU_TUBE = "YOU_TUBE"
    EMAIL = "EMAIL"
    ISSUE = "ISSUE"
    INITIATIVE = "INITIATIVE"
    PULL_REQUEST = "PULL_REQUEST"
    COMMIT = "COMMIT"
    SEARCH = "SEARCH"
    CALENDAR = "CALENDAR"
    CRM = "CRM"
    RESEARCH = "RESEARCH"
    ENTITY = "ENTITY"
    ATTIO = "ATTIO"
    SALESFORCE = "SALESFORCE"
    HUB_SPOT = "HUB_SPOT"
    HUB_SPOT_CONVERSATIONS = "HUB_SPOT_CONVERSATIONS"
    CONFLUENCE = "CONFLUENCE"
    MEETING = "MEETING"
    HRIS = "HRIS"
    INTERCOM_CONVERSATIONS = "INTERCOM_CONVERSATIONS"
    PRODUCTLANE = "PRODUCTLANE"


class H3ResolutionTypes(str, Enum):
    R0 = "R0"
    R1 = "R1"
    R2 = "R2"
    R3 = "R3"
    R4 = "R4"
    R5 = "R5"
    R6 = "R6"
    R7 = "R7"
    R8 = "R8"
    R9 = "R9"
    R10 = "R10"
    R11 = "R11"
    R12 = "R12"
    R13 = "R13"
    R14 = "R14"
    R15 = "R15"


class DropboxAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class GoogleDriveAuthenticationTypes(str, Enum):
    SERVICE_ACCOUNT = "SERVICE_ACCOUNT"
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class AnthropicEffortLevels(str, Enum):
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"
    MAX = "MAX"


class LinearAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    O_AUTH = "O_AUTH"
    CONNECTOR = "CONNECTOR"


class RerankingModelServiceTypes(str, Enum):
    COHERE = "COHERE"
    JINA = "JINA"
    VOYAGE = "VOYAGE"


class AttioAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class PlaceFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class SourceTypes(str, Enum):
    CONTENT = "CONTENT"
    CONVERSATION = "CONVERSATION"
    PERSONA = "PERSONA"


class InvestmentFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class IntercomAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class MedicalDrugFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class RetrievalStrategyTypes(str, Enum):
    CONTENT = "CONTENT"
    CHUNK = "CHUNK"
    SECTION = "SECTION"


class MedicalGuidelineFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class OpenAIVisionDetailLevels(str, Enum):
    HIGH = "HIGH"
    LOW = "LOW"


class ContentPublishingFormats(str, Enum):
    PNG = "PNG"
    JPEG = "JPEG"
    WEBP = "WEBP"
    MP3 = "MP3"
    MP4 = "MP4"
    TEXT = "TEXT"
    MARKDOWN = "MARKDOWN"
    HTML = "HTML"
    SVG = "SVG"


class AzureDocumentIntelligenceModels(str, Enum):
    READ_OCR = "READ_OCR"
    LAYOUT = "LAYOUT"
    INVOICE = "INVOICE"
    RECEIPT = "RECEIPT"
    IDENTIFICATION_DOCUMENT = "IDENTIFICATION_DOCUMENT"
    US_HEALTH_INSURANCE_CARD = "US_HEALTH_INSURANCE_CARD"
    US_TAX_FORM = "US_TAX_FORM"
    US_TAX_FORM_W2 = "US_TAX_FORM_W2"
    US_TAX_FORM1098 = "US_TAX_FORM1098"
    US_TAX_FORM1098_E = "US_TAX_FORM1098_E"
    US_TAX_FORM1098_T = "US_TAX_FORM1098_T"
    US_TAX_FORM1099 = "US_TAX_FORM1099"
    US_MARRIAGE_CERTIFICATE = "US_MARRIAGE_CERTIFICATE"
    US_MORTGAGE1003 = "US_MORTGAGE1003"
    US_MORTGAGE1008 = "US_MORTGAGE1008"
    US_MORTGAGE_DISCLOSURE = "US_MORTGAGE_DISCLOSURE"
    CREDIT_CARD = "CREDIT_CARD"
    US_PAY_STUB = "US_PAY_STUB"
    US_BANK_CHECK = "US_BANK_CHECK"
    US_BANK_STATEMENT = "US_BANK_STATEMENT"


class GitHubAuthenticationTypes(str, Enum):
    PERSONAL_ACCESS_TOKEN = "PERSONAL_ACCESS_TOKEN"
    O_AUTH = "O_AUTH"
    CONNECTOR = "CONNECTOR"


class GoogleEmailAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class JinaModels(str, Enum):
    CLIP_IMAGE = "CLIP_IMAGE"
    EMBED = "EMBED"
    EMBED_3_0 = "EMBED_3_0"
    EMBED_4_0 = "EMBED_4_0"
    CUSTOM = "CUSTOM"


class OneDriveAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class GraphStrategyTypes(str, Enum):
    EXTRACT_ENTITIES_FILTER = "EXTRACT_ENTITIES_FILTER"
    EXTRACT_ENTITIES_GRAPH = "EXTRACT_ENTITIES_GRAPH"
    NONE = "NONE"


class MicrosoftTeamsAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class AuthenticationServiceTypes(str, Enum):
    AUTH0 = "AUTH0"
    MICROSOFT_GRAPH = "MICROSOFT_GRAPH"
    CLERK = "CLERK"
    GOOGLE = "GOOGLE"
    O_AUTH = "O_AUTH"
    ARCADE = "ARCADE"
    TOKEN = "TOKEN"
    API_KEY = "API_KEY"


class RevisionStrategyTypes(str, Enum):
    REVISE = "REVISE"
    CUSTOM = "CUSTOM"
    NONE = "NONE"


class DeepseekModels(str, Enum):
    REASONER = "REASONER"
    CHAT = "CHAT"
    CODER = "CODER"
    CUSTOM = "CUSTOM"


class AnthropicModels(str, Enum):
    CLAUDE_2 = "CLAUDE_2"
    CLAUDE_2_0 = "CLAUDE_2_0"
    CLAUDE_2_1 = "CLAUDE_2_1"
    CLAUDE_INSTANT_1 = "CLAUDE_INSTANT_1"
    CLAUDE_INSTANT_1_2 = "CLAUDE_INSTANT_1_2"
    CLAUDE_3_OPUS = "CLAUDE_3_OPUS"
    CLAUDE_3_OPUS_20240229 = "CLAUDE_3_OPUS_20240229"
    CLAUDE_3_SONNET = "CLAUDE_3_SONNET"
    CLAUDE_3_SONNET_20240229 = "CLAUDE_3_SONNET_20240229"
    CLAUDE_3_HAIKU = "CLAUDE_3_HAIKU"
    CLAUDE_3_HAIKU_20240307 = "CLAUDE_3_HAIKU_20240307"
    CLAUDE_3_5_SONNET = "CLAUDE_3_5_SONNET"
    CLAUDE_3_5_SONNET_20241022 = "CLAUDE_3_5_SONNET_20241022"
    CLAUDE_3_5_SONNET_20240620 = "CLAUDE_3_5_SONNET_20240620"
    CLAUDE_3_5_HAIKU = "CLAUDE_3_5_HAIKU"
    CLAUDE_3_5_HAIKU_20241022 = "CLAUDE_3_5_HAIKU_20241022"
    CLAUDE_3_7_SONNET = "CLAUDE_3_7_SONNET"
    CLAUDE_3_7_SONNET_20250219 = "CLAUDE_3_7_SONNET_20250219"
    CLAUDE_4_SONNET = "CLAUDE_4_SONNET"
    CLAUDE_4_SONNET_20250514 = "CLAUDE_4_SONNET_20250514"
    CLAUDE_4_5_SONNET = "CLAUDE_4_5_SONNET"
    CLAUDE_4_5_SONNET_20250929 = "CLAUDE_4_5_SONNET_20250929"
    CLAUDE_4_6_SONNET = "CLAUDE_4_6_SONNET"
    CLAUDE_4_6_SONNET_20260217 = "CLAUDE_4_6_SONNET_20260217"
    CLAUDE_4_6_SONNET_1_M = "CLAUDE_4_6_SONNET_1_M"
    CLAUDE_4_6_SONNET_1_M_20260217 = "CLAUDE_4_6_SONNET_1_M_20260217"
    CLAUDE_4_5_OPUS = "CLAUDE_4_5_OPUS"
    CLAUDE_4_5_OPUS_20251101 = "CLAUDE_4_5_OPUS_20251101"
    CLAUDE_4_6_OPUS = "CLAUDE_4_6_OPUS"
    CLAUDE_4_6_OPUS_20260205 = "CLAUDE_4_6_OPUS_20260205"
    CLAUDE_4_6_OPUS_1_M = "CLAUDE_4_6_OPUS_1_M"
    CLAUDE_4_6_OPUS_1_M_20260205 = "CLAUDE_4_6_OPUS_1_M_20260205"
    CLAUDE_4_OPUS = "CLAUDE_4_OPUS"
    CLAUDE_4_OPUS_20250514 = "CLAUDE_4_OPUS_20250514"
    CLAUDE_4_1_OPUS = "CLAUDE_4_1_OPUS"
    CLAUDE_4_1_OPUS_20250805 = "CLAUDE_4_1_OPUS_20250805"
    CLAUDE_4_5_HAIKU = "CLAUDE_4_5_HAIKU"
    CLAUDE_4_5_HAIKU_20251001 = "CLAUDE_4_5_HAIKU_20251001"
    CUSTOM = "CUSTOM"


class TwelveLabsSegmentationMethods(str, Enum):
    DYNAMIC = "DYNAMIC"
    FIXED = "FIXED"


class TimedPolicyRecurrenceTypes(str, Enum):
    ONCE = "ONCE"
    REPEAT = "REPEAT"
    MONITOR = "MONITOR"


class ElevenLabsModels(str, Enum):
    MULTILINGUAL_V1 = "MULTILINGUAL_V1"
    MULTILINGUAL_V2 = "MULTILINGUAL_V2"
    ENGLISH_V1 = "ENGLISH_V1"
    FLASH_V2 = "FLASH_V2"
    FLASH_V2_5 = "FLASH_V2_5"
    TURBO_V2 = "TURBO_V2"
    TURBO_V2_5 = "TURBO_V2_5"


class BlobListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class AttioFeedAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class GroqModels(str, Enum):
    LLAMA_4_MAVERICK_17B = "LLAMA_4_MAVERICK_17B"
    LLAMA_4_SCOUT_17B = "LLAMA_4_SCOUT_17B"
    DEEPSEEK_R1_LLAMA_70B_PREVIEW = "DEEPSEEK_R1_LLAMA_70B_PREVIEW"
    MIXTRAL_8X7B_INSTRUCT = "MIXTRAL_8X7B_INSTRUCT"
    LLAMA_3_3_70B = "LLAMA_3_3_70B"
    LLAMA_3_2_90B_VISION_PREVIEW = "LLAMA_3_2_90B_VISION_PREVIEW"
    LLAMA_3_2_11B_VISION_PREVIEW = "LLAMA_3_2_11B_VISION_PREVIEW"
    LLAMA_3_2_3B_PREVIEW = "LLAMA_3_2_3B_PREVIEW"
    LLAMA_3_2_1B_PREVIEW = "LLAMA_3_2_1B_PREVIEW"
    LLAMA_3_1_8B = "LLAMA_3_1_8B"
    LLAMA_3_70B = "LLAMA_3_70B"
    LLAMA_3_8B = "LLAMA_3_8B"
    KIMI_K2_32B = "KIMI_K2_32B"
    QWEN_3_32B = "QWEN_3_32B"
    CUSTOM = "CUSTOM"


class OrderByTypes(str, Enum):
    NAME = "NAME"
    CREATION_DATE = "CREATION_DATE"
    ORIGINAL_DATE = "ORIGINAL_DATE"
    RELEVANCE = "RELEVANCE"


class OpenAIVideoModels(str, Enum):
    SORA_2 = "SORA_2"
    SORA_2_PRO = "SORA_2_PRO"
    CUSTOM = "CUSTOM"


class ConnectorTypes(str, Enum):
    INTEGRATION = "INTEGRATION"
    AUTHENTICATION = "AUTHENTICATION"
    SITE = "SITE"


class ModelTypes(str, Enum):
    COMPLETION = "COMPLETION"
    TEXT_EMBEDDING = "TEXT_EMBEDDING"
    IMAGE_EMBEDDING = "IMAGE_EMBEDDING"
    MULTIMODAL_EMBEDDING = "MULTIMODAL_EMBEDDING"
    RERANKING = "RERANKING"


class AssemblyAIModels(str, Enum):
    BEST = "BEST"
    NANO = "NANO"


class FileTypes(str, Enum):
    VIDEO = "VIDEO"
    AUDIO = "AUDIO"
    IMAGE = "IMAGE"
    ANIMATION = "ANIMATION"
    DOCUMENT = "DOCUMENT"
    EMAIL = "EMAIL"
    CODE = "CODE"
    DATA = "DATA"
    PACKAGE = "PACKAGE"
    SHAPE = "SHAPE"
    POINT_CLOUD = "POINT_CLOUD"
    GEOMETRY = "GEOMETRY"
    DRAWING = "DRAWING"
    SUBTITLES = "SUBTITLES"
    MANIFEST = "MANIFEST"
    UNKNOWN = "UNKNOWN"


class DeepgramModels(str, Enum):
    NOVA3_MEDICAL = "NOVA3_MEDICAL"
    NOVA3 = "NOVA3"
    NOVA2 = "NOVA2"
    NOVA2_MEETING = "NOVA2_MEETING"
    NOVA2_PHONECALL = "NOVA2_PHONECALL"
    NOVA2_VOICEMAIL = "NOVA2_VOICEMAIL"
    NOVA2_FINANCE = "NOVA2_FINANCE"
    NOVA2_CONVERSATIONAL_AI = "NOVA2_CONVERSATIONAL_AI"
    NOVA2_VIDEO = "NOVA2_VIDEO"
    NOVA2_MEDICAL = "NOVA2_MEDICAL"
    NOVA2_DRIVETHRU = "NOVA2_DRIVETHRU"
    NOVA2_AUTOMOTIVE = "NOVA2_AUTOMOTIVE"
    WHISPER_TINY = "WHISPER_TINY"
    WHISPER_SMALL = "WHISPER_SMALL"
    WHISPER_BASE = "WHISPER_BASE"
    WHISPER_MEDIUM = "WHISPER_MEDIUM"
    WHISPER_LARGE = "WHISPER_LARGE"


class MedicalContraindicationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MCPServerTypes(str, Enum):
    REMOTE_SSE = "REMOTE_SSE"
    REMOTE_HTTP = "REMOTE_HTTP"
    LOCAL_NPX = "LOCAL_NPX"


class MailPriority(str, Enum):
    NORMAL = "NORMAL"
    LOW = "LOW"
    HIGH = "HIGH"


class ConversationTypes(str, Enum):
    CONTENT = "CONTENT"
    AGENT = "AGENT"


class OpenAIImageModels(str, Enum):
    GPT_IMAGE_1 = "GPT_IMAGE_1"
    GPT_IMAGE_1_MINI = "GPT_IMAGE_1_MINI"
    GPT_IMAGE_1_5 = "GPT_IMAGE_1_5"
    CUSTOM = "CUSTOM"


class SummarizationTypes(str, Enum):
    SUMMARY = "SUMMARY"
    KEYWORDS = "KEYWORDS"
    BULLETS = "BULLETS"
    HEADLINES = "HEADLINES"
    POSTS = "POSTS"
    CHAPTERS = "CHAPTERS"
    QUESTIONS = "QUESTIONS"
    QUOTES = "QUOTES"
    GEOTAG = "GEOTAG"
    CUSTOM = "CUSTOM"


class OrderDirectionTypes(str, Enum):
    ASCENDING = "ASCENDING"
    DESCENDING = "DESCENDING"


class CalendarEventVisibility(str, Enum):
    DEFAULT = "DEFAULT"
    PUBLIC = "PUBLIC"
    PRIVATE = "PRIVATE"
    CONFIDENTIAL = "CONFIDENTIAL"


class MedicalDeviceFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class OperationTypes(str, Enum):
    QUERY = "QUERY"
    MUTATION = "MUTATION"


class SpecificationTypes(str, Enum):
    COMPLETION = "COMPLETION"
    AGENTIC = "AGENTIC"
    TEXT_EMBEDDING = "TEXT_EMBEDDING"
    IMAGE_EMBEDDING = "IMAGE_EMBEDDING"
    EXTRACTION = "EXTRACTION"
    CLASSIFICATION = "CLASSIFICATION"
    SUMMARIZATION = "SUMMARIZATION"
    PREPARATION = "PREPARATION"
    MULTIMODAL_EMBEDDING = "MULTIMODAL_EMBEDDING"


class CalendarEventStatus(str, Enum):
    CONFIRMED = "CONFIRMED"
    TENTATIVE = "TENTATIVE"
    CANCELLED = "CANCELLED"


class MetadataTypes(str, Enum):
    CONTENT = "CONTENT"
    CONVERSATION = "CONVERSATION"


class VoyageModels(str, Enum):
    VOYAGE = "VOYAGE"
    VOYAGE_3_5 = "VOYAGE_3_5"
    VOYAGE_3_5_LITE = "VOYAGE_3_5_LITE"
    VOYAGE_3_0_LARGE = "VOYAGE_3_0_LARGE"
    VOYAGE_3_0 = "VOYAGE_3_0"
    VOYAGE_LITE_3_0 = "VOYAGE_LITE_3_0"
    VOYAGE_CODE_3_0 = "VOYAGE_CODE_3_0"
    VOYAGE_FINANCE_2_0 = "VOYAGE_FINANCE_2_0"
    VOYAGE_MULTILINGUAL_2_0 = "VOYAGE_MULTILINGUAL_2_0"
    VOYAGE_LAW_2_0 = "VOYAGE_LAW_2_0"
    VOYAGE_CODE_2_0 = "VOYAGE_CODE_2_0"
    CUSTOM = "CUSTOM"


class AlertTypes(str, Enum):
    PROMPT = "PROMPT"


class MeetingContentTypes(str, Enum):
    TRANSCRIPT = "TRANSCRIPT"
    RECORDING = "RECORDING"
    PREFERRED = "PREFERRED"


class SalesforceAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class ContentTypes(str, Enum):
    FILE = "FILE"
    PAGE = "PAGE"
    MESSAGE = "MESSAGE"
    TEXT = "TEXT"
    POST = "POST"
    EMAIL = "EMAIL"
    EVENT = "EVENT"
    ISSUE = "ISSUE"
    INITIATIVE = "INITIATIVE"
    PULL_REQUEST = "PULL_REQUEST"
    COMMIT = "COMMIT"
    MEMORY = "MEMORY"
    TRANSCRIPT = "TRANSCRIPT"


class EntityExtractionServiceTypes(str, Enum):
    MODEL_TEXT = "MODEL_TEXT"
    MODEL_IMAGE = "MODEL_IMAGE"
    OPEN_AI_IMAGE = "OPEN_AI_IMAGE"
    AZURE_COGNITIVE_SERVICES_IMAGE = "AZURE_COGNITIVE_SERVICES_IMAGE"
    AZURE_COGNITIVE_SERVICES_TEXT = "AZURE_COGNITIVE_SERVICES_TEXT"
    HUME_EMOTION = "HUME_EMOTION"


class TwitterListingTypes(str, Enum):
    POSTS = "POSTS"
    MENTIONS = "MENTIONS"
    RECENT_SEARCH = "RECENT_SEARCH"


class RenditionTypes(str, Enum):
    CONTENT = "CONTENT"


class ConversationRoleTypes(str, Enum):
    SYSTEM = "SYSTEM"
    ASSISTANT = "ASSISTANT"
    USER = "USER"
    TOOL = "TOOL"


class GoogleCalendarAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class MailImportance(str, Enum):
    NORMAL = "NORMAL"
    LOW = "LOW"
    HIGH = "HIGH"


class SalesforceIssueAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class FeedListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class HubSpotAuthenticationTypes(str, Enum):
    USER = "USER"
    PRIVATE_APP = "PRIVATE_APP"
    CONNECTOR = "CONNECTOR"


class HubSpotIssueAuthenticationTypes(str, Enum):
    USER = "USER"
    PRIVATE_APP = "PRIVATE_APP"
    CONNECTOR = "CONNECTOR"


class NotionAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class SalesforceFeedAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class GoogleVideoModels(str, Enum):
    VEO_3 = "VEO_3"
    VEO_3_FAST = "VEO_3_FAST"
    VEO_3_1_PREVIEW = "VEO_3_1_PREVIEW"
    VEO_3_1_FAST_PREVIEW = "VEO_3_1_FAST_PREVIEW"
    CUSTOM = "CUSTOM"


class OpenAIImageSizeTypes(str, Enum):
    SQUARE = "SQUARE"
    LANDSCAPE = "LANDSCAPE"
    PORTRAIT = "PORTRAIT"
    AUTO = "AUTO"


class MedicalIndicationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class ViewTypes(str, Enum):
    CONTENT = "CONTENT"


class RepoFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class GustoAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class BedrockModels(str, Enum):
    LLAMA_4_MAVERICK_17B = "LLAMA_4_MAVERICK_17B"
    LLAMA_4_SCOUT_17B = "LLAMA_4_SCOUT_17B"
    CLAUDE_3_7_SONNET = "CLAUDE_3_7_SONNET"
    NOVA_PREMIER = "NOVA_PREMIER"
    NOVA_PRO = "NOVA_PRO"
    CUSTOM = "CUSTOM"


class AzureDocumentIntelligenceVersions(str, Enum):
    V2023_07_31 = "V2023_07_31"
    V2024_02_29_PREVIEW = "V2024_02_29_PREVIEW"
    V2024_07_31_PREVIEW = "V2024_07_31_PREVIEW"
    V2024_11_30 = "V2024_11_30"


class ArcadeProviders(str, Enum):
    GOOGLE = "GOOGLE"
    GIT_HUB = "GIT_HUB"
    MICROSOFT = "MICROSOFT"


class LabelFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class ContentFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"
    ORIGINAL_DATE = "ORIGINAL_DATE"
    OBSERVABLE = "OBSERVABLE"
    CONTENT_TYPE = "CONTENT_TYPE"
    FILE_TYPE = "FILE_TYPE"
    FORMAT = "FORMAT"
    FORMAT_NAME = "FORMAT_NAME"
    FILE_EXTENSION = "FILE_EXTENSION"
    FILE_SIZE = "FILE_SIZE"
    DEVICE_TYPE = "DEVICE_TYPE"
    IMAGE_MAKE = "IMAGE_MAKE"
    IMAGE_MODEL = "IMAGE_MODEL"
    IMAGE_SOFTWARE = "IMAGE_SOFTWARE"
    AUDIO_AUTHOR = "AUDIO_AUTHOR"
    AUDIO_SERIES = "AUDIO_SERIES"
    AUDIO_PUBLISHER = "AUDIO_PUBLISHER"
    VIDEO_MAKE = "VIDEO_MAKE"
    VIDEO_MODEL = "VIDEO_MODEL"
    VIDEO_SOFTWARE = "VIDEO_SOFTWARE"
    DOCUMENT_AUTHOR = "DOCUMENT_AUTHOR"
    DOCUMENT_PUBLISHER = "DOCUMENT_PUBLISHER"
    DOCUMENT_IS_ENCRYPTED = "DOCUMENT_IS_ENCRYPTED"
    DOCUMENT_HAS_DIGITAL_SIGNATURE = "DOCUMENT_HAS_DIGITAL_SIGNATURE"
    EMAIL_PRIORITY = "EMAIL_PRIORITY"
    EMAIL_SENSITIVITY = "EMAIL_SENSITIVITY"
    ISSUE_PROJECT = "ISSUE_PROJECT"
    ISSUE_TEAM = "ISSUE_TEAM"
    ISSUE_PRIORITY = "ISSUE_PRIORITY"
    ISSUE_STATUS = "ISSUE_STATUS"
    ISSUE_TYPE = "ISSUE_TYPE"


class RegexSourceTypes(str, Enum):
    MARKDOWN = "MARKDOWN"
    METADATA = "METADATA"


class OccurrenceTypes(str, Enum):
    IMAGE = "IMAGE"
    TIME = "TIME"
    TEXT = "TEXT"
    TURN = "TURN"


class InvestmentFundFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class EntityOwners(str, Enum):
    SYSTEM = "SYSTEM"
    PROJECT = "PROJECT"


class ElevenLabsScribeModels(str, Enum):
    SCRIBE_V1 = "SCRIBE_V1"
    SCRIBE_V2 = "SCRIBE_V2"


class EmailListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class BambooHRAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"


class ResourceConnectorTypes(str, Enum):
    AMAZON = "AMAZON"
    AZURE = "AZURE"
    GOOGLE = "GOOGLE"


class DistributionServiceTypes(str, Enum):
    NOTION = "NOTION"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    ONE_DRIVE = "ONE_DRIVE"
    CONFLUENCE = "CONFLUENCE"
    SLACK = "SLACK"
    GMAIL = "GMAIL"
    MICROSOFT_OUTLOOK = "MICROSOFT_OUTLOOK"
    HUB_SPOT = "HUB_SPOT"
    SALESFORCE = "SALESFORCE"
    ATTIO = "ATTIO"
    GOOGLE_CALENDAR = "GOOGLE_CALENDAR"
    MICROSOFT_CALENDAR = "MICROSOFT_CALENDAR"
    LINEAR = "LINEAR"
    JIRA = "JIRA"
    GOOGLE_DOCS = "GOOGLE_DOCS"
    MICROSOFT_WORD = "MICROSOFT_WORD"
    SHARE_POINT = "SHARE_POINT"
    DISCORD = "DISCORD"
    MICROSOFT_TEAMS = "MICROSOFT_TEAMS"
    TWITTER = "TWITTER"
    GIT_HUB = "GIT_HUB"
    ATTIO_TASKS = "ATTIO_TASKS"


class ReductoExtractionModes(str, Enum):
    OCR = "OCR"
    METADATA = "METADATA"
    HYBRID = "HYBRID"


class MedicalConditionFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class EntityState(str, Enum):
    INITIALIZED = "INITIALIZED"
    RESTARTED = "RESTARTED"
    CREATED = "CREATED"
    INGESTED = "INGESTED"
    INDEXED = "INDEXED"
    PREPARED = "PREPARED"
    SANITIZED = "SANITIZED"
    EXTRACTED = "EXTRACTED"
    ENRICHED = "ENRICHED"
    CLASSIFIED = "CLASSIFIED"
    CHANGED = "CHANGED"
    ARCHIVED = "ARCHIVED"
    APPROVED = "APPROVED"
    REJECTED = "REJECTED"
    PENDING = "PENDING"
    QUEUED = "QUEUED"
    OPENED = "OPENED"
    CLOSED = "CLOSED"
    FINISHED = "FINISHED"
    PAUSED = "PAUSED"
    RUNNING = "RUNNING"
    SUBSCRIBED = "SUBSCRIBED"
    ERRORED = "ERRORED"
    ENABLED = "ENABLED"
    LIMITED = "LIMITED"
    RESOLVED = "RESOLVED"
    DISABLED = "DISABLED"
    DELETED = "DELETED"


class GitHubPullRequestAuthenticationTypes(str, Enum):
    PERSONAL_ACCESS_TOKEN = "PERSONAL_ACCESS_TOKEN"
    O_AUTH = "O_AUTH"
    CONNECTOR = "CONNECTOR"


class TextRoles(str, Enum):
    PAGE_HEADER = "PAGE_HEADER"
    PAGE_FOOTER = "PAGE_FOOTER"
    PAGE_NUMBER = "PAGE_NUMBER"
    TITLE = "TITLE"
    SECTION_HEADING = "SECTION_HEADING"
    FOOTNOTE = "FOOTNOTE"
    CODE = "CODE"
    LIST_ITEM = "LIST_ITEM"
    HEADING1 = "HEADING1"
    HEADING2 = "HEADING2"
    HEADING3 = "HEADING3"
    HEADING4 = "HEADING4"
    HEADING5 = "HEADING5"
    HEADING6 = "HEADING6"
    TABLE_COLUMN_HEADER = "TABLE_COLUMN_HEADER"
    TABLE_ROW_HEADER = "TABLE_ROW_HEADER"
    TABLE_CORNER_HEADER = "TABLE_CORNER_HEADER"
    TABLE_CELL = "TABLE_CELL"
    TABLE_CAPTION = "TABLE_CAPTION"
    TABLE_HEADER = "TABLE_HEADER"
    TABLE = "TABLE"
    IMAGE = "IMAGE"
    IMAGE_CAPTION = "IMAGE_CAPTION"
    FIGURE = "FIGURE"
    FIGURE_CAPTION = "FIGURE_CAPTION"
    BUTTON = "BUTTON"
    DIAGRAM = "DIAGRAM"
    DIAGRAM_CAPTION = "DIAGRAM_CAPTION"
    WATERMARK = "WATERMARK"
    EQUATION = "EQUATION"
    PARAGRAPH = "PARAGRAPH"
    CHECKBOX = "CHECKBOX"
    RADIO_BUTTON = "RADIO_BUTTON"
    COLUMN_HEADER = "COLUMN_HEADER"
    ROW_HEADER = "ROW_HEADER"
    CORNER_HEADER = "CORNER_HEADER"


class YouTubeTypes(str, Enum):
    VIDEO = "VIDEO"
    VIDEOS = "VIDEOS"
    PLAYLIST = "PLAYLIST"
    CHANNEL = "CHANNEL"


class NotionTypes(str, Enum):
    PAGE = "PAGE"
    DATABASE = "DATABASE"


class PromptStrategyTypes(str, Enum):
    OPTIMIZE_SEARCH = "OPTIMIZE_SEARCH"
    REWRITE = "REWRITE"
    NONE = "NONE"


class ReductoOcrModes(str, Enum):
    STANDARD = "STANDARD"
    AGENTIC = "AGENTIC"


class ConfluenceTypes(str, Enum):
    SPACE = "SPACE"
    PAGE = "PAGE"


class GoogleImageAspectRatioTypes(str, Enum):
    SQUARE_1X1 = "SQUARE_1X1"
    PORTRAIT_1X4 = "PORTRAIT_1X4"
    PORTRAIT_1X8 = "PORTRAIT_1X8"
    PORTRAIT_2X3 = "PORTRAIT_2X3"
    LANDSCAPE_3X2 = "LANDSCAPE_3X2"
    PORTRAIT_3X4 = "PORTRAIT_3X4"
    LANDSCAPE_4X1 = "LANDSCAPE_4X1"
    LANDSCAPE_4X3 = "LANDSCAPE_4X3"
    PORTRAIT_4X5 = "PORTRAIT_4X5"
    LANDSCAPE_5X4 = "LANDSCAPE_5X4"
    LANDSCAPE_8X1 = "LANDSCAPE_8X1"
    PORTRAIT_9X16 = "PORTRAIT_9X16"
    LANDSCAPE_16X9 = "LANDSCAPE_16X9"
    LANDSCAPE_21X9 = "LANDSCAPE_21X9"


class EmbeddingTypes(str, Enum):
    TEXT = "TEXT"
    IMAGE = "IMAGE"
    AUDIO = "AUDIO"
    VIDEO = "VIDEO"
    MULTIMODAL = "MULTIMODAL"


class MedicalTestFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class ReductoOcrSystems(str, Enum):
    HIGHRES = "HIGHRES"
    MULTILINGUAL = "MULTILINGUAL"
    COMBINED = "COMBINED"


class SoftwareFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class MailSensitivity(str, Enum):
    NONE = "NONE"
    NORMAL = "NORMAL"
    PERSONAL = "PERSONAL"
    PRIVATE = "PRIVATE"
    COMPANY_CONFIDENTIAL = "COMPANY_CONFIDENTIAL"


class MedicalStudyFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class SdkTypes(str, Enum):
    DOTNET = "DOTNET"
    PYTHON = "PYTHON"
    NODE_JS = "NODE_JS"


class GoogleThinkingLevels(str, Enum):
    MINIMAL = "MINIMAL"
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"


class SearchTypes(str, Enum):
    KEYWORD = "KEYWORD"
    VECTOR = "VECTOR"
    HYBRID = "HYBRID"


class MedicalTherapyFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class FacetValueTypes(str, Enum):
    VALUE = "VALUE"
    RANGE = "RANGE"
    OBJECT = "OBJECT"


class ZendeskIssueAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class ReductoEnrichmentModes(str, Enum):
    STANDARD = "STANDARD"
    PAGE = "PAGE"
    TABLE = "TABLE"


class TrelloTypes(str, Enum):
    CARD = "CARD"
    BOARD = "BOARD"


class ContentPublishingServiceTypes(str, Enum):
    ELEVEN_LABS_AUDIO = "ELEVEN_LABS_AUDIO"
    OPEN_AI_IMAGE = "OPEN_AI_IMAGE"
    GOOGLE_IMAGE = "GOOGLE_IMAGE"
    OPEN_AI_VIDEO = "OPEN_AI_VIDEO"
    GOOGLE_VIDEO = "GOOGLE_VIDEO"
    TEXT = "TEXT"
    QUIVER_IMAGE = "QUIVER_IMAGE"
    PARALLEL_RESEARCH = "PARALLEL_RESEARCH"


class LinkedInPostContentTypes(str, Enum):
    PHOTOS = "PHOTOS"
    VIDEOS = "VIDEOS"
    DOCUMENTS = "DOCUMENTS"
    JOBS = "JOBS"
    COLLABORATIVE_ARTICLES = "COLLABORATIVE_ARTICLES"
    LIVE_VIDEOS = "LIVE_VIDEOS"


class StorageGateTypes(str, Enum):
    MODEL = "MODEL"
    WEBHOOK = "WEBHOOK"


class ParallelProcessors(str, Enum):
    LITE = "LITE"
    BASE = "BASE"
    CORE = "CORE"
    CORE2X = "CORE2X"
    PRO = "PRO"
    ULTRA = "ULTRA"
    ULTRA2X = "ULTRA2X"
    ULTRA4X = "ULTRA4X"
    ULTRA8X = "ULTRA8X"
    LITE_FAST = "LITE_FAST"
    BASE_FAST = "BASE_FAST"
    CORE_FAST = "CORE_FAST"
    CORE2X_FAST = "CORE2X_FAST"
    PRO_FAST = "PRO_FAST"
    ULTRA_FAST = "ULTRA_FAST"
    ULTRA2X_FAST = "ULTRA2X_FAST"
    ULTRA4X_FAST = "ULTRA4X_FAST"
    ULTRA8X_FAST = "ULTRA8X_FAST"


class ObservableTypes(str, Enum):
    CATEGORY = "CATEGORY"
    LABEL = "LABEL"
    EMOTION = "EMOTION"
    EVENT = "EVENT"
    INVESTMENT = "INVESTMENT"
    INVESTMENT_FUND = "INVESTMENT_FUND"
    ORGANIZATION = "ORGANIZATION"
    PERSON = "PERSON"
    PLACE = "PLACE"
    PRODUCT = "PRODUCT"
    REPO = "REPO"
    SOFTWARE = "SOFTWARE"
    MEDICAL_STUDY = "MEDICAL_STUDY"
    MEDICAL_CONDITION = "MEDICAL_CONDITION"
    MEDICAL_GUIDELINE = "MEDICAL_GUIDELINE"
    MEDICAL_DRUG = "MEDICAL_DRUG"
    MEDICAL_DRUG_CLASS = "MEDICAL_DRUG_CLASS"
    MEDICAL_INDICATION = "MEDICAL_INDICATION"
    MEDICAL_CONTRAINDICATION = "MEDICAL_CONTRAINDICATION"
    MEDICAL_TEST = "MEDICAL_TEST"
    MEDICAL_DEVICE = "MEDICAL_DEVICE"
    MEDICAL_THERAPY = "MEDICAL_THERAPY"
    MEDICAL_PROCEDURE = "MEDICAL_PROCEDURE"


class CalendarReminderMethod(str, Enum):
    EMAIL = "EMAIL"
    POPUP = "POPUP"
    SMS = "SMS"


class MedicalDrugClassFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class GitHubCommitAuthenticationTypes(str, Enum):
    PERSONAL_ACCESS_TOKEN = "PERSONAL_ACCESS_TOKEN"
    O_AUTH = "O_AUTH"
    CONNECTOR = "CONNECTOR"


class CrustdataWatcherSignalTypes(str, Enum):
    COMPANY_JOB_POSTINGS = "COMPANY_JOB_POSTINGS"
    COMPANY_LINKED_IN_POSTS = "COMPANY_LINKED_IN_POSTS"
    COMPANY_NEWS_MENTIONS = "COMPANY_NEWS_MENTIONS"
    COMPANY_FUNDING_ROUND = "COMPANY_FUNDING_ROUND"
    COMPANY_HEADCOUNT_GROWTH = "COMPANY_HEADCOUNT_GROWTH"
    PERSON_PROFILE_UPDATES = "PERSON_PROFILE_UPDATES"
    PERSON_LINKED_IN_POSTS = "PERSON_LINKED_IN_POSTS"
    JOB_POSTING_BY_KEYWORD = "JOB_POSTING_BY_KEYWORD"
    NEW_FUNDING_ANNOUNCEMENTS = "NEW_FUNDING_ANNOUNCEMENTS"
    LINKED_IN_POST_WITH_KEYWORD = "LINKED_IN_POST_WITH_KEYWORD"
    HEADCOUNT_GROWTH_DISCOVERY = "HEADCOUNT_GROWTH_DISCOVERY"
    PERSON_STARTING_NEW_POSITION = "PERSON_STARTING_NEW_POSITION"
    JOB_POSTING_BY_LOCATION = "JOB_POSTING_BY_LOCATION"
    COMPANY_DEPARTMENT_HEADCOUNT = "COMPANY_DEPARTMENT_HEADCOUNT"
    FIRST_PERSON_HIRED_IN_DEPARTMENT = "FIRST_PERSON_HIRED_IN_DEPARTMENT"
    FIRST_PERSON_HIRED_INTERNATIONALLY = "FIRST_PERSON_HIRED_INTERNATIONALLY"
    EMPLOYEE_LOCATION_TWO_COUNTRIES = "EMPLOYEE_LOCATION_TWO_COUNTRIES"
    HEADCOUNT_GROWTH_OVER_BASELINE = "HEADCOUNT_GROWTH_OVER_BASELINE"
    PERSON_DISCOVERY_VIA_FILTERS = "PERSON_DISCOVERY_VIA_FILTERS"


class EmotionFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class QuiverImageModels(str, Enum):
    ARROW_PREVIEW = "ARROW_PREVIEW"
    CUSTOM = "CUSTOM"


class EntityTypes(str, Enum):
    ACTIVITY = "ACTIVITY"
    AGENT = "AGENT"
    ALERT = "ALERT"
    CATEGORY = "CATEGORY"
    COLLECTION = "COLLECTION"
    CONNECTOR = "CONNECTOR"
    CONTENT = "CONTENT"
    CONVERSATION = "CONVERSATION"
    EVENT = "EVENT"
    FACT = "FACT"
    FEED = "FEED"
    INVESTMENT = "INVESTMENT"
    INVESTMENT_FUND = "INVESTMENT_FUND"
    JOB = "JOB"
    LABEL = "LABEL"
    EMOTION = "EMOTION"
    METADATA = "METADATA"
    MEDICAL_STUDY = "MEDICAL_STUDY"
    MEDICAL_CONDITION = "MEDICAL_CONDITION"
    MEDICAL_GUIDELINE = "MEDICAL_GUIDELINE"
    MEDICAL_DRUG = "MEDICAL_DRUG"
    MEDICAL_DRUG_CLASS = "MEDICAL_DRUG_CLASS"
    MEDICAL_INDICATION = "MEDICAL_INDICATION"
    MEDICAL_CONTRAINDICATION = "MEDICAL_CONTRAINDICATION"
    MEDICAL_TEST = "MEDICAL_TEST"
    MEDICAL_DEVICE = "MEDICAL_DEVICE"
    MEDICAL_THERAPY = "MEDICAL_THERAPY"
    MEDICAL_PROCEDURE = "MEDICAL_PROCEDURE"
    OBSERVATION = "OBSERVATION"
    ORGANIZATION = "ORGANIZATION"
    PERSON = "PERSON"
    PERSONA = "PERSONA"
    PLACE = "PLACE"
    PRODUCT = "PRODUCT"
    PROJECT = "PROJECT"
    RENDITION = "RENDITION"
    REPO = "REPO"
    SITE = "SITE"
    SKILL = "SKILL"
    SOFTWARE = "SOFTWARE"
    SPECIFICATION = "SPECIFICATION"
    USER = "USER"
    VIEW = "VIEW"
    WORKFLOW = "WORKFLOW"


class ConversationSearchTypes(str, Enum):
    NONE = "NONE"
    VECTOR = "VECTOR"
    HYBRID = "HYBRID"


class EventFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class WaterfallDepths(str, Enum):
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"


class ZendeskAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class EntityResolutionStrategyTypes(str, Enum):
    NONE = "NONE"
    AUTOMATIC = "AUTOMATIC"


class AttioMeetingAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class OpenAIModels(str, Enum):
    GPT35_TURBO = "GPT35_TURBO"
    GPT35_TURBO_0613 = "GPT35_TURBO_0613"
    GPT35_TURBO_16K = "GPT35_TURBO_16K"
    GPT35_TURBO_16K_0613 = "GPT35_TURBO_16K_0613"
    GPT35_TURBO_16K_1106 = "GPT35_TURBO_16K_1106"
    GPT35_TURBO_16K_0125 = "GPT35_TURBO_16K_0125"
    GPT4 = "GPT4"
    GPT4_0613 = "GPT4_0613"
    GPT4_TURBO_VISION_128K = "GPT4_TURBO_VISION_128K"
    GPT4_TURBO_VISION_128K_1106 = "GPT4_TURBO_VISION_128K_1106"
    GPT4_32K = "GPT4_32K"
    GPT4_32K_0613 = "GPT4_32K_0613"
    GPT4_TURBO_128K = "GPT4_TURBO_128K"
    GPT4_TURBO_128K_1106 = "GPT4_TURBO_128K_1106"
    GPT4_TURBO_128K_0125 = "GPT4_TURBO_128K_0125"
    GPT4_TURBO_128K_20240409 = "GPT4_TURBO_128K_20240409"
    GPT4O_128K_20240513 = "GPT4O_128K_20240513"
    GPT4O_128K_20240806 = "GPT4O_128K_20240806"
    GPT4O_128K_20241120 = "GPT4O_128K_20241120"
    GPT4O_128K = "GPT4O_128K"
    GPT4O_MINI_128K_20240718 = "GPT4O_MINI_128K_20240718"
    GPT4O_MINI_128K = "GPT4O_MINI_128K"
    GPT4O_CHAT_128K = "GPT4O_CHAT_128K"
    GPT41_NANO_1024K = "GPT41_NANO_1024K"
    GPT41_NANO_1024K_20250414 = "GPT41_NANO_1024K_20250414"
    GPT41_MINI_1024K = "GPT41_MINI_1024K"
    GPT41_MINI_1024K_20250414 = "GPT41_MINI_1024K_20250414"
    GPT41_1024K = "GPT41_1024K"
    GPT41_1024K_20250414 = "GPT41_1024K_20250414"
    GPT45_PREVIEW_128K = "GPT45_PREVIEW_128K"
    GPT45_PREVIEW_128K_20250227 = "GPT45_PREVIEW_128K_20250227"
    GPT5_CHAT_400K = "GPT5_CHAT_400K"
    GPT5_NANO_400K = "GPT5_NANO_400K"
    GPT5_NANO_400K_20250807 = "GPT5_NANO_400K_20250807"
    GPT5_MINI_400K = "GPT5_MINI_400K"
    GPT5_MINI_400K_20250807 = "GPT5_MINI_400K_20250807"
    GPT5_400K = "GPT5_400K"
    GPT5_400K_20250807 = "GPT5_400K_20250807"
    GPT51_400K = "GPT51_400K"
    GPT51_400K_20251113 = "GPT51_400K_20251113"
    GPT52_400K = "GPT52_400K"
    GPT52_400K_20251211 = "GPT52_400K_20251211"
    GPT54_NANO_400K = "GPT54_NANO_400K"
    GPT54_NANO_400K_20260317 = "GPT54_NANO_400K_20260317"
    GPT54_MINI_400K = "GPT54_MINI_400K"
    GPT54_MINI_400K_20260317 = "GPT54_MINI_400K_20260317"
    GPT54_1024K = "GPT54_1024K"
    GPT54_1024K_20260305 = "GPT54_1024K_20260305"
    O1_MINI_128K = "O1_MINI_128K"
    O1_MINI_128K_20240912 = "O1_MINI_128K_20240912"
    O1_PREVIEW_128K = "O1_PREVIEW_128K"
    O1_PREVIEW_128K_20240912 = "O1_PREVIEW_128K_20240912"
    O1_200K = "O1_200K"
    O1_200K_20241217 = "O1_200K_20241217"
    O3_MINI_200K = "O3_MINI_200K"
    O3_MINI_200K_20250131 = "O3_MINI_200K_20250131"
    O3_200K = "O3_200K"
    O3_200K_20250416 = "O3_200K_20250416"
    O4_MINI_200K = "O4_MINI_200K"
    O4_MINI_200K_20250416 = "O4_MINI_200K_20250416"
    ADA_002 = "ADA_002"
    EMBEDDING_3_SMALL = "EMBEDDING_3_SMALL"
    EMBEDDING_3_LARGE = "EMBEDDING_3_LARGE"
    CUSTOM = "CUSTOM"


class FeedServiceTypes(str, Enum):
    GOOGLE_BLOB = "GOOGLE_BLOB"
    S3_BLOB = "S3_BLOB"
    AZURE_BLOB = "AZURE_BLOB"
    AZURE_FILE = "AZURE_FILE"
    SHARE_POINT = "SHARE_POINT"
    ONE_DRIVE = "ONE_DRIVE"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    DROPBOX = "DROPBOX"
    BOX = "BOX"
    GOOGLE_EMAIL = "GOOGLE_EMAIL"
    MICROSOFT_EMAIL = "MICROSOFT_EMAIL"
    ATLASSIAN_JIRA = "ATLASSIAN_JIRA"
    ATLASSIAN_CONFLUENCE = "ATLASSIAN_CONFLUENCE"
    TRELLO = "TRELLO"
    LINEAR = "LINEAR"
    GIT_HUB_ISSUES = "GIT_HUB_ISSUES"
    GIT_HUB_PULL_REQUESTS = "GIT_HUB_PULL_REQUESTS"
    GIT_HUB_COMMITS = "GIT_HUB_COMMITS"
    GIT_HUB = "GIT_HUB"
    INTERCOM_ARTICLES = "INTERCOM_ARTICLES"
    ZENDESK_ARTICLES = "ZENDESK_ARTICLES"
    INTERCOM_TICKETS = "INTERCOM_TICKETS"
    ZENDESK_TICKETS = "ZENDESK_TICKETS"
    GOOGLE_CALENDAR = "GOOGLE_CALENDAR"
    MICROSOFT_CALENDAR = "MICROSOFT_CALENDAR"
    GOOGLE_CONTACTS = "GOOGLE_CONTACTS"
    MICROSOFT_CONTACTS = "MICROSOFT_CONTACTS"
    ATTIO_OBJECTS = "ATTIO_OBJECTS"
    ATTIO_TASKS = "ATTIO_TASKS"
    ATTIO_NOTES = "ATTIO_NOTES"
    SALESFORCE_OBJECTS = "SALESFORCE_OBJECTS"
    SALESFORCE_TASKS = "SALESFORCE_TASKS"
    SALESFORCE_NOTES = "SALESFORCE_NOTES"
    HUB_SPOT_OBJECTS = "HUB_SPOT_OBJECTS"
    HUB_SPOT_TASKS = "HUB_SPOT_TASKS"
    HUB_SPOT_TICKETS = "HUB_SPOT_TICKETS"
    ASANA = "ASANA"
    MONDAY = "MONDAY"
    HUB_SPOT_NOTES = "HUB_SPOT_NOTES"
    HUB_SPOT_MEETING = "HUB_SPOT_MEETING"
    HUB_SPOT_CONVERSATIONS = "HUB_SPOT_CONVERSATIONS"
    FIREFLIES = "FIREFLIES"
    ATTIO_MEETING = "ATTIO_MEETING"
    FATHOM = "FATHOM"
    KRISP = "KRISP"
    SALESFORCE_ECI = "SALESFORCE_ECI"
    PARALLEL = "PARALLEL"
    CRUSTDATA = "CRUSTDATA"
    BAMBOO_HR = "BAMBOO_HR"
    GUSTO_HRIS = "GUSTO_HRIS"
    INTERCOM_CONVERSATIONS = "INTERCOM_CONVERSATIONS"
    JIRA_EPICS = "JIRA_EPICS"
    GIT_HUB_MILESTONES = "GIT_HUB_MILESTONES"
    LINEAR_INITIATIVES = "LINEAR_INITIATIVES"
    PRODUCTLANE_THREADS = "PRODUCTLANE_THREADS"
    PRODUCTLANE_ISSUES = "PRODUCTLANE_ISSUES"
    PRODUCTLANE_OBJECTS = "PRODUCTLANE_OBJECTS"
    PRODUCTLANE_CHANGELOGS = "PRODUCTLANE_CHANGELOGS"
    PRODUCTLANE_ARTICLES = "PRODUCTLANE_ARTICLES"
    NYNE = "NYNE"


class TextTypes(str, Enum):
    PLAIN = "PLAIN"
    MARKDOWN = "MARKDOWN"
    HTML = "HTML"


class SearchServiceTypes(str, Enum):
    PARALLEL = "PARALLEL"
    TAVILY = "TAVILY"
    EXA = "EXA"
    EXA_CODE = "EXA_CODE"
    PERPLEXITY = "PERPLEXITY"
    PODSCAN = "PODSCAN"
    CRUSTDATA = "CRUSTDATA"


class FeedSyncMode(str, Enum):
    ARCHIVE = "ARCHIVE"
    MIRROR = "MIRROR"


class FilePreparationServiceTypes(str, Enum):
    AZURE_DOCUMENT_INTELLIGENCE = "AZURE_DOCUMENT_INTELLIGENCE"
    DEEPGRAM = "DEEPGRAM"
    DOCUMENT = "DOCUMENT"
    EMAIL = "EMAIL"
    PAGE = "PAGE"
    REDUCTO_DOCUMENT = "REDUCTO_DOCUMENT"
    MODEL_DOCUMENT = "MODEL_DOCUMENT"
    ASSEMBLY_AI = "ASSEMBLY_AI"
    MISTRAL_DOCUMENT = "MISTRAL_DOCUMENT"
    ELEVEN_LABS_SCRIBE = "ELEVEN_LABS_SCRIBE"


class GitHubRepositorySortTypes(str, Enum):
    ALPHABETICAL = "ALPHABETICAL"
    RANKED = "RANKED"


class UserTypes(str, Enum):
    HUMAN = "HUMAN"
    AGENT = "AGENT"


class GoogleImageResolutionTypes(str, Enum):
    RESOLUTION_512 = "RESOLUTION_512"
    RESOLUTION_1_K = "RESOLUTION_1_K"
    RESOLUTION_2_K = "RESOLUTION_2_K"
    RESOLUTION_4_K = "RESOLUTION_4_K"


class CalendarAttendeeResponseStatus(str, Enum):
    NEEDS_ACTION = "NEEDS_ACTION"
    DECLINED = "DECLINED"
    TENTATIVE = "TENTATIVE"
    ACCEPTED = "ACCEPTED"


class SearchQueryTypes(str, Enum):
    SIMPLE = "SIMPLE"
    FULL = "FULL"


class OrganizationFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class OpenAIReasoningEffortLevels(str, Enum):
    MINIMAL = "MINIMAL"
    LOW = "LOW"
    MEDIUM = "MEDIUM"
    HIGH = "HIGH"


class MistralModels(str, Enum):
    MIXTRAL_8X7B_INSTRUCT = "MIXTRAL_8X7B_INSTRUCT"
    MISTRAL_NEMO = "MISTRAL_NEMO"
    MISTRAL_SMALL = "MISTRAL_SMALL"
    MISTRAL_MEDIUM = "MISTRAL_MEDIUM"
    MISTRAL_LARGE = "MISTRAL_LARGE"
    PIXTRAL_12B_2409 = "PIXTRAL_12B_2409"
    PIXTRAL_LARGE = "PIXTRAL_LARGE"
    MISTRAL_EMBED = "MISTRAL_EMBED"
    CUSTOM = "CUSTOM"


class StorageGateRejectionActions(str, Enum):
    DELETE = "DELETE"
    REJECT = "REJECT"


class ImageProjectionTypes(str, Enum):
    EQUIRECTANGULAR = "EQUIRECTANGULAR"
    CYLINDRICAL = "CYLINDRICAL"


class HubSpotFeedAuthenticationTypes(str, Enum):
    USER = "USER"
    PRIVATE_APP = "PRIVATE_APP"
    CONNECTOR = "CONNECTOR"


class IntegrationServiceTypes(str, Enum):
    SLACK = "SLACK"
    WEB_HOOK = "WEB_HOOK"
    EMAIL = "EMAIL"
    TWITTER = "TWITTER"
    MCP = "MCP"


class CerebrasModels(str, Enum):
    LLAMA_4_SCOUT_17B = "LLAMA_4_SCOUT_17B"
    LLAMA_3_3_70B = "LLAMA_3_3_70B"
    LLAMA_3_1_8B = "LLAMA_3_1_8B"
    QWEN_3_32B = "QWEN_3_32B"
    CUSTOM = "CUSTOM"


class IntercomIssueAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class CohereModels(str, Enum):
    EMBED_ENGLISH_3_0 = "EMBED_ENGLISH_3_0"
    EMBED_MULTILINGUAL_3_0 = "EMBED_MULTILINGUAL_3_0"
    COMMAND_R = "COMMAND_R"
    COMMAND_R_202403 = "COMMAND_R_202403"
    COMMAND_R_202408 = "COMMAND_R_202408"
    COMMAND_R_PLUS = "COMMAND_R_PLUS"
    COMMAND_R_PLUS_202404 = "COMMAND_R_PLUS_202404"
    COMMAND_R_PLUS_202408 = "COMMAND_R_PLUS_202408"
    COMMAND_R7_B_202412 = "COMMAND_R7_B_202412"
    COMMAND_A = "COMMAND_A"
    COMMAND_A_202503 = "COMMAND_A_202503"
    CUSTOM = "CUSTOM"


class SharePointAuthenticationTypes(str, Enum):
    APPLICATION = "APPLICATION"
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class ConversationStrategyTypes(str, Enum):
    WINDOWED = "WINDOWED"
    SUMMARIZED = "SUMMARIZED"


class AsanaAuthenticationTypes(str, Enum):
    PERSONAL_ACCESS_TOKEN = "PERSONAL_ACCESS_TOKEN"
    O_AUTH = "O_AUTH"


class MicrosoftEmailAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class EnvironmentTypes(str, Enum):
    DEVELOPMENT = "DEVELOPMENT"
    PRODUCTION = "PRODUCTION"


class ExaSearchTypes(str, Enum):
    AUTO = "AUTO"
    INSTANT = "INSTANT"
    FAST = "FAST"
    DEEP = "DEEP"
    NEURAL = "NEURAL"


class GoogleContactsAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class CalendarRecurrencePattern(str, Enum):
    DAILY = "DAILY"
    WEEKLY = "WEEKLY"
    MONTHLY = "MONTHLY"
    YEARLY = "YEARLY"


class RelationshipDirections(str, Enum):
    INCOMING = "INCOMING"
    OUTGOING = "OUTGOING"


class ModelServiceTypes(str, Enum):
    GOOGLE = "GOOGLE"
    ANTHROPIC = "ANTHROPIC"
    AZURE_AI = "AZURE_AI"
    AZURE_OPEN_AI = "AZURE_OPEN_AI"
    OPEN_AI = "OPEN_AI"
    REPLICATE = "REPLICATE"
    GROQ = "GROQ"
    CEREBRAS = "CEREBRAS"
    MISTRAL = "MISTRAL"
    COHERE = "COHERE"
    DEEPSEEK = "DEEPSEEK"
    JINA = "JINA"
    VOYAGE = "VOYAGE"
    BEDROCK = "BEDROCK"
    XAI = "XAI"
    TWELVE_LABS = "TWELVE_LABS"
    QUIVER = "QUIVER"


class AgentChannelTypes(str, Enum):
    VOICE = "VOICE"
    EMAIL = "EMAIL"
    SLACK = "SLACK"
    TEAMS = "TEAMS"
    DISCORD = "DISCORD"


class AgentTypes(str, Enum):
    AGENT = "AGENT"


class MicrosoftCalendarAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class ReplicateModels(str, Enum):
    MISTRAL_7B = "MISTRAL_7B"
    MISTRAL_7B_INSTRUCT = "MISTRAL_7B_INSTRUCT"
    LLAMA_2_7B = "LLAMA_2_7B"
    LLAMA_2_13B = "LLAMA_2_13B"
    LLAMA_2_70B = "LLAMA_2_70B"
    LLAMA_2_7B_CHAT = "LLAMA_2_7B_CHAT"
    LLAMA_2_13B_CHAT = "LLAMA_2_13B_CHAT"
    LLAMA_2_70B_CHAT = "LLAMA_2_70B_CHAT"
    CUSTOM = "CUSTOM"


class SiteTypes(str, Enum):
    WATCH = "WATCH"
    SWEEP = "SWEEP"
    STORAGE = "STORAGE"


class ExtractionTypes(str, Enum):
    ENTITIES = "ENTITIES"
    FACTS = "FACTS"


class TimeIntervalTypes(str, Enum):
    MINUTE = "MINUTE"
    HOUR = "HOUR"
    DAY = "DAY"
    WEEK = "WEEK"
    MONTH = "MONTH"
    QUARTER = "QUARTER"
    YEAR = "YEAR"


class OrientationTypes(str, Enum):
    TOP_LEFT = "TOP_LEFT"
    TOP_RIGHT = "TOP_RIGHT"
    BOTTOM_RIGHT = "BOTTOM_RIGHT"
    BOTTOM_LEFT = "BOTTOM_LEFT"
    LEFT_TOP = "LEFT_TOP"
    RIGHT_TOP = "RIGHT_TOP"
    RIGHT_BOTTOM = "RIGHT_BOTTOM"
    LEFT_BOTTOM = "LEFT_BOTTOM"


class ProductFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class FilterMode(str, Enum):
    ANY = "ANY"
    ONLY = "ONLY"
    ALL = "ALL"


class OAuthProviders(str, Enum):
    DROPBOX = "DROPBOX"
    BOX = "BOX"
    GOOGLE = "GOOGLE"
    MICROSOFT = "MICROSOFT"
    GIT_HUB = "GIT_HUB"
    SLACK = "SLACK"
    HUB_SPOT = "HUB_SPOT"
    NOTION = "NOTION"
    ATLASSIAN = "ATLASSIAN"
    INTERCOM = "INTERCOM"
    ZENDESK = "ZENDESK"
    ATTIO = "ATTIO"
    SALESFORCE = "SALESFORCE"
    LINEAR = "LINEAR"
    TWITTER = "TWITTER"


class ConfluenceAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class UnitTypes(str, Enum):
    KILOMETER = "KILOMETER"
    METER = "METER"
    CENTIMETER = "CENTIMETER"
    MILLIMETER = "MILLIMETER"
    MICROMETER = "MICROMETER"
    NANOMETER = "NANOMETER"
    ANGSTROM = "ANGSTROM"
    DECIMETER = "DECIMETER"
    DECAMETER = "DECAMETER"
    HECTOMETER = "HECTOMETER"
    GIGAMETER = "GIGAMETER"
    ASTRONOMICAL_UNIT = "ASTRONOMICAL_UNIT"
    LIGHT_YEAR = "LIGHT_YEAR"
    PARSEC = "PARSEC"
    MILE = "MILE"
    YARD = "YARD"
    FOOT = "FOOT"
    INCH = "INCH"
    MIL = "MIL"
    MICRO_INCH = "MICRO_INCH"
    CUSTOM = "CUSTOM"
    UNITLESS = "UNITLESS"


class ParallelGenerators(str, Enum):
    BASE = "BASE"
    CORE = "CORE"
    PRO = "PRO"


class AttioIssueAuthenticationTypes(str, Enum):
    API_KEY = "API_KEY"
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class ContentIndexingServiceTypes(str, Enum):
    AZURE_AI_LANGUAGE = "AZURE_AI_LANGUAGE"


class MicrosoftContactsAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class CategoryFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class PersonFacetTypes(str, Enum):
    CREATION_DATE = "CREATION_DATE"


class VideoAspectRatioTypes(str, Enum):
    LANDSCAPE_16X9 = "LANDSCAPE_16X9"
    PORTRAIT_9X16 = "PORTRAIT_9X16"


class StoragePolicyTypes(str, Enum):
    ARCHIVE = "ARCHIVE"
    MINIMIZE = "MINIMIZE"


class LinkedInPostListingTypes(str, Enum):
    COMPANY = "COMPANY"
    PERSON = "PERSON"
    KEYWORD_SEARCH = "KEYWORD_SEARCH"


class TwelveLabsEmbeddingOptions(str, Enum):
    VISUAL = "VISUAL"
    AUDIO = "AUDIO"
    TRANSCRIPTION = "TRANSCRIPTION"


class CalendarListingTypes(str, Enum):
    PAST = "PAST"
    NEW = "NEW"


class EntityEnrichmentServiceTypes(str, Enum):
    PARALLEL = "PARALLEL"
    DIFFBOT = "DIFFBOT"
    WIKIPEDIA = "WIKIPEDIA"
    CRUNCHBASE = "CRUNCHBASE"
    FHIR = "FHIR"
    RADAR = "RADAR"
    CRUSTDATA = "CRUSTDATA"
    NYNE = "NYNE"
    WATERFALL = "WATERFALL"


class DeviceTypes(str, Enum):
    DRONE = "DRONE"
    ROBOT = "ROBOT"
    MOBILE = "MOBILE"
    CAMERA = "CAMERA"
    STREAM = "STREAM"
    SCREEN = "SCREEN"
    GEOSPATIAL = "GEOSPATIAL"
    UNKNOWN = "UNKNOWN"


class VideoSizeTypes(str, Enum):
    HD_PORTRAIT = "HD_PORTRAIT"
    HD_LANDSCAPE = "HD_LANDSCAPE"
    FULL_HD_PORTRAIT = "FULL_HD_PORTRAIT"
    FULL_HD_LANDSCAPE = "FULL_HD_LANDSCAPE"


class ContentClassificationServiceTypes(str, Enum):
    REGEX = "REGEX"
    MODEL = "MODEL"


class BoxAuthenticationTypes(str, Enum):
    USER = "USER"
    CONNECTOR = "CONNECTOR"


class ContentSourceTypes(str, Enum):
    FRAME = "FRAME"
    DOCUMENT = "DOCUMENT"
    TRANSCRIPT = "TRANSCRIPT"


class GoogleModels(str, Enum):
    GEMINI_2_5_PRO = "GEMINI_2_5_PRO"
    GEMINI_2_5_PRO_PREVIEW = "GEMINI_2_5_PRO_PREVIEW"
    GEMINI_2_5_PRO_EXPERIMENTAL = "GEMINI_2_5_PRO_EXPERIMENTAL"
    GEMINI_3_PRO_PREVIEW = "GEMINI_3_PRO_PREVIEW"
    GEMINI_3_1_PRO_PREVIEW = "GEMINI_3_1_PRO_PREVIEW"
    GEMINI_3_FLASH_PREVIEW = "GEMINI_3_FLASH_PREVIEW"
    GEMINI_2_5_FLASH = "GEMINI_2_5_FLASH"
    GEMINI_FLASH_LATEST = "GEMINI_FLASH_LATEST"
    GEMINI_2_5_FLASH_PREVIEW = "GEMINI_2_5_FLASH_PREVIEW"
    GEMINI_2_5_FLASH_LITE = "GEMINI_2_5_FLASH_LITE"
    GEMINI_FLASH_LITE_LATEST = "GEMINI_FLASH_LITE_LATEST"
    GEMINI_2_0_PRO_EXPERIMENTAL = "GEMINI_2_0_PRO_EXPERIMENTAL"
    GEMINI_2_0_FLASH_THINKING_EXPERIMENTAL = "GEMINI_2_0_FLASH_THINKING_EXPERIMENTAL"
    GEMINI_2_0_FLASH_EXPERIMENTAL = "GEMINI_2_0_FLASH_EXPERIMENTAL"
    GEMINI_2_0_FLASH = "GEMINI_2_0_FLASH"
    GEMINI_2_0_FLASH_001 = "GEMINI_2_0_FLASH_001"
    GEMINI_1_5_FLASH_8B = "GEMINI_1_5_FLASH_8B"
    GEMINI_1_5_FLASH_8B_001 = "GEMINI_1_5_FLASH_8B_001"
    GEMINI_1_5_FLASH = "GEMINI_1_5_FLASH"
    GEMINI_1_5_FLASH_001 = "GEMINI_1_5_FLASH_001"
    GEMINI_1_5_PRO = "GEMINI_1_5_PRO"
    GEMINI_1_5_PRO_001 = "GEMINI_1_5_PRO_001"
    GEMINI_1_5_FLASH_002 = "GEMINI_1_5_FLASH_002"
    GEMINI_1_5_PRO_002 = "GEMINI_1_5_PRO_002"
    EMBEDDING_004 = "EMBEDDING_004"
    GEMINI_EMBEDDING_001 = "GEMINI_EMBEDDING_001"
    GEMINI_EMBEDDING_2_PREVIEW = "GEMINI_EMBEDDING_2_PREVIEW"
    CUSTOM = "CUSTOM"


class ApplyPolicy(str, Enum):
    BEFORE_RESOLVER = "BEFORE_RESOLVER"
    AFTER_RESOLVER = "AFTER_RESOLVER"
    VALIDATION = "VALIDATION"


class FeedConnectorTypes(str, Enum):
    GOOGLE = "GOOGLE"
    AMAZON = "AMAZON"
    AZURE = "AZURE"
    SHARE_POINT = "SHARE_POINT"
    ONE_DRIVE = "ONE_DRIVE"
    GOOGLE_DRIVE = "GOOGLE_DRIVE"
    DROPBOX = "DROPBOX"
    BOX = "BOX"
    GOOGLE_EMAIL = "GOOGLE_EMAIL"
    MICROSOFT_EMAIL = "MICROSOFT_EMAIL"
    ATLASSIAN = "ATLASSIAN"
    LINEAR = "LINEAR"
    GIT_HUB = "GIT_HUB"
    INTERCOM = "INTERCOM"
    ZENDESK = "ZENDESK"
    GOOGLE_CALENDAR = "GOOGLE_CALENDAR"
    MICROSOFT_CALENDAR = "MICROSOFT_CALENDAR"
    GOOGLE_CONTACTS = "GOOGLE_CONTACTS"
    MICROSOFT_CONTACTS = "MICROSOFT_CONTACTS"
    ATTIO = "ATTIO"
    SALESFORCE = "SALESFORCE"
    HUB_SPOT = "HUB_SPOT"
    ASANA = "ASANA"
    MONDAY = "MONDAY"
    FIREFLIES = "FIREFLIES"
    ATTIO_MEETING = "ATTIO_MEETING"
    FATHOM = "FATHOM"
    KRISP = "KRISP"
    SALESFORCE_ECI = "SALESFORCE_ECI"
    PARALLEL = "PARALLEL"
    BAMBOO_HR = "BAMBOO_HR"
    GUSTO = "GUSTO"
    PRODUCTLANE = "PRODUCTLANE"


class BillableMetrics(str, Enum):
    BYTES = "BYTES"
    TOKENS = "TOKENS"
    LENGTH = "LENGTH"
    TIME = "TIME"
    UNITS = "UNITS"
    COST = "COST"
    REQUESTS = "REQUESTS"
    CREDITS = "CREDITS"


class TwelveLabsEmbeddingScopes(str, Enum):
    CLIP = "CLIP"
    ASSET = "ASSET"


class JiraAuthenticationTypes(str, Enum):
    TOKEN = "TOKEN"
    CONNECTOR = "CONNECTOR"


class IntercomConversationsAuthenticationTypes(str, Enum):
    ACCESS_TOKEN = "ACCESS_TOKEN"
    CONNECTOR = "CONNECTOR"


class GoogleImageModels(str, Enum):
    GEMINI_2_5_FLASH_IMAGE_PREVIEW = "GEMINI_2_5_FLASH_IMAGE_PREVIEW"
    GEMINI_3_PRO_IMAGE_PREVIEW = "GEMINI_3_PRO_IMAGE_PREVIEW"
    GEMINI_3_1_FLASH_IMAGE_PREVIEW = "GEMINI_3_1_FLASH_IMAGE_PREVIEW"
    CUSTOM = "CUSTOM"


class XAIModels(str, Enum):
    GROK_4 = "GROK_4"
    GROK_3 = "GROK_3"
    GROK_3_MINI = "GROK_3_MINI"
    CUSTOM = "CUSTOM"
