# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class RejectContent(BaseModel):
    reject_content: Optional["RejectContentRejectContent"] = Field(
        alias="rejectContent"
    )


class RejectContentRejectContent(BaseModel):
    id: str
    state: EntityState


RejectContent.model_rebuild()
