# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllPersonas(BaseModel):
    delete_all_personas: Optional[
        list[Optional["DeleteAllPersonasDeleteAllPersonas"]]
    ] = Field(alias="deleteAllPersonas")


class DeleteAllPersonasDeleteAllPersonas(BaseModel):
    id: str
    state: EntityState


DeleteAllPersonas.model_rebuild()
