# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteInvestment(BaseModel):
    delete_investment: Optional["DeleteInvestmentDeleteInvestment"] = Field(
        alias="deleteInvestment"
    )


class DeleteInvestmentDeleteInvestment(BaseModel):
    id: str
    state: EntityState


DeleteInvestment.model_rebuild()
