# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class FeedExists(BaseModel):
    feed_exists: Optional["FeedExistsFeedExists"] = Field(alias="feedExists")


class FeedExistsFeedExists(BaseModel):
    result: Optional[bool]


FeedExists.model_rebuild()
