# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EnrichPersons(BaseModel):
    enrich_persons: Optional[list[Optional["EnrichPersonsEnrichPersons"]]] = Field(
        alias="enrichPersons"
    )


class EnrichPersonsEnrichPersons(BaseModel):
    id: str
    name: str


EnrichPersons.model_rebuild()
