# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteViews(BaseModel):
    delete_views: Optional[list[Optional["DeleteViewsDeleteViews"]]] = Field(
        alias="deleteViews"
    )


class DeleteViewsDeleteViews(BaseModel):
    id: str
    state: EntityState


DeleteViews.model_rebuild()
