# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from .base_model import BaseModel
from .enums import ObservableTypes


class QueryObservables(BaseModel):
    observables: Optional["QueryObservablesObservables"]


class QueryObservablesObservables(BaseModel):
    results: Optional[list[Optional["QueryObservablesObservablesResults"]]]


class QueryObservablesObservablesResults(BaseModel):
    type: ObservableTypes
    observable: "QueryObservablesObservablesResultsObservable"


class QueryObservablesObservablesResultsObservable(BaseModel):
    id: str
    name: Optional[str]


QueryObservables.model_rebuild()
QueryObservablesObservables.model_rebuild()
QueryObservablesObservablesResults.model_rebuild()
