# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryJiraProjects(BaseModel):
    jira_projects: Optional["QueryJiraProjectsJiraProjects"] = Field(
        alias="jiraProjects"
    )


class QueryJiraProjectsJiraProjects(BaseModel):
    results: Optional[list[Optional["QueryJiraProjectsJiraProjectsResults"]]]


class QueryJiraProjectsJiraProjectsResults(BaseModel):
    identifier: Optional[str]
    name: Optional[str]
    key: Optional[str]


QueryJiraProjects.model_rebuild()
QueryJiraProjectsJiraProjects.model_rebuild()
