# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllViews(BaseModel):
    delete_all_views: Optional[list[Optional["DeleteAllViewsDeleteAllViews"]]] = Field(
        alias="deleteAllViews"
    )


class DeleteAllViewsDeleteAllViews(BaseModel):
    id: str
    state: EntityState


DeleteAllViews.model_rebuild()
