# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryLabels(BaseModel):
    labels: Optional["QueryLabelsLabels"]


class QueryLabelsLabels(BaseModel):
    results: Optional[list[Optional["QueryLabelsLabelsResults"]]]


class QueryLabelsLabelsResults(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    feeds: Optional[list[Optional["QueryLabelsLabelsResultsFeeds"]]]


class QueryLabelsLabelsResultsFeeds(BaseModel):
    id: str
    name: str


QueryLabels.model_rebuild()
QueryLabelsLabels.model_rebuild()
QueryLabelsLabelsResults.model_rebuild()
