# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryEmotions(BaseModel):
    emotions: Optional["QueryEmotionsEmotions"]


class QueryEmotionsEmotions(BaseModel):
    results: Optional[list[Optional["QueryEmotionsEmotionsResults"]]]


class QueryEmotionsEmotionsResults(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    feeds: Optional[list[Optional["QueryEmotionsEmotionsResultsFeeds"]]]


class QueryEmotionsEmotionsResultsFeeds(BaseModel):
    id: str
    name: str


QueryEmotions.model_rebuild()
QueryEmotionsEmotions.model_rebuild()
QueryEmotionsEmotionsResults.model_rebuild()
