# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteLabels(BaseModel):
    delete_labels: Optional[list[Optional["DeleteLabelsDeleteLabels"]]] = Field(
        alias="deleteLabels"
    )


class DeleteLabelsDeleteLabels(BaseModel):
    id: str
    state: EntityState


DeleteLabels.model_rebuild()
