# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteWorkflows(BaseModel):
    delete_workflows: Optional[list[Optional["DeleteWorkflowsDeleteWorkflows"]]] = (
        Field(alias="deleteWorkflows")
    )


class DeleteWorkflowsDeleteWorkflows(BaseModel):
    id: str
    state: EntityState


DeleteWorkflows.model_rebuild()
