# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteConnector(BaseModel):
    delete_connector: Optional["DeleteConnectorDeleteConnector"] = Field(
        alias="deleteConnector"
    )


class DeleteConnectorDeleteConnector(BaseModel):
    id: str
    state: EntityState


DeleteConnector.model_rebuild()
