# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QuerySlackChannels(BaseModel):
    slack_channels: Optional["QuerySlackChannelsSlackChannels"] = Field(
        alias="slackChannels"
    )


class QuerySlackChannelsSlackChannels(BaseModel):
    results: Optional[list[str]]


QuerySlackChannels.model_rebuild()
