# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteEvents(BaseModel):
    delete_events: Optional[list[Optional["DeleteEventsDeleteEvents"]]] = Field(
        alias="deleteEvents"
    )


class DeleteEventsDeleteEvents(BaseModel):
    id: str
    state: EntityState


DeleteEvents.model_rebuild()
