# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePersonas(BaseModel):
    delete_personas: Optional[list[Optional["DeletePersonasDeletePersonas"]]] = Field(
        alias="deletePersonas"
    )


class DeletePersonasDeletePersonas(BaseModel):
    id: str
    state: EntityState


DeletePersonas.model_rebuild()
