# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EnrichOrganizations(BaseModel):
    enrich_organizations: Optional[
        list[Optional["EnrichOrganizationsEnrichOrganizations"]]
    ] = Field(alias="enrichOrganizations")


class EnrichOrganizationsEnrichOrganizations(BaseModel):
    id: str
    name: str


EnrichOrganizations.model_rebuild()
