# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteEmotions(BaseModel):
    delete_emotions: Optional[list[Optional["DeleteEmotionsDeleteEmotions"]]] = Field(
        alias="deleteEmotions"
    )


class DeleteEmotionsDeleteEmotions(BaseModel):
    id: str
    state: EntityState


DeleteEmotions.model_rebuild()
