# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class RestartContent(BaseModel):
    restart_content: Optional["RestartContentRestartContent"] = Field(
        alias="restartContent"
    )


class RestartContentRestartContent(BaseModel):
    id: str
    state: EntityState


RestartContent.model_rebuild()
