# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import AgentTypes, EntityState


class CreateAgent(BaseModel):
    create_agent: Optional["CreateAgentCreateAgent"] = Field(alias="createAgent")


class CreateAgentCreateAgent(BaseModel):
    id: str
    name: str
    state: EntityState
    type: AgentTypes


CreateAgent.model_rebuild()
