# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class AddConversationsToCollections(BaseModel):
    add_conversations_to_collections: Optional[
        list[Optional["AddConversationsToCollectionsAddConversationsToCollections"]]
    ] = Field(alias="addConversationsToCollections")


class AddConversationsToCollectionsAddConversationsToCollections(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[
            Optional[
                "AddConversationsToCollectionsAddConversationsToCollectionsContents"
            ]
        ]
    ]


class AddConversationsToCollectionsAddConversationsToCollectionsContents(BaseModel):
    id: str
    name: str


AddConversationsToCollections.model_rebuild()
AddConversationsToCollectionsAddConversationsToCollections.model_rebuild()
