# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryPersonsClusters(BaseModel):
    persons: Optional["QueryPersonsClustersPersons"]


class QueryPersonsClustersPersons(BaseModel):
    results: Optional[list[Optional["QueryPersonsClustersPersonsResults"]]]
    clusters: Optional["QueryPersonsClustersPersonsClusters"]


class QueryPersonsClustersPersonsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryPersonsClustersPersonsResultsOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[list[Optional["QueryPersonsClustersPersonsResultsFeeds"]]]
    links: Optional[list[Optional["QueryPersonsClustersPersonsResultsLinks"]]]
    workflow: Optional["QueryPersonsClustersPersonsResultsWorkflow"]
    location: Optional["QueryPersonsClustersPersonsResultsLocation"]
    h_3: Optional["QueryPersonsClustersPersonsResultsH3"] = Field(alias="h3")
    address: Optional["QueryPersonsClustersPersonsResultsAddress"]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")
    phone_number: Optional[str] = Field(alias="phoneNumber")
    birth_date: Optional[Any] = Field(alias="birthDate")
    title: Optional[str]
    occupation: Optional[str]
    education: Optional[str]
    works_for: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsWorksFor"]]
    ] = Field(alias="worksFor")
    affiliation: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsAffiliation"]]
    ]
    member_of: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsMemberOf"]]
    ] = Field(alias="memberOf")
    alumni_of: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsAlumniOf"]]
    ] = Field(alias="alumniOf")
    birth_place: Optional["QueryPersonsClustersPersonsResultsBirthPlace"] = Field(
        alias="birthPlace"
    )
    death_place: Optional["QueryPersonsClustersPersonsResultsDeathPlace"] = Field(
        alias="deathPlace"
    )
    home_location: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsHomeLocation"]]
    ] = Field(alias="homeLocation")
    work_location: Optional[
        list[Optional["QueryPersonsClustersPersonsResultsWorkLocation"]]
    ] = Field(alias="workLocation")


class QueryPersonsClustersPersonsResultsOwner(BaseModel):
    id: str


class QueryPersonsClustersPersonsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryPersonsClustersPersonsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryPersonsClustersPersonsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryPersonsClustersPersonsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryPersonsClustersPersonsResultsWorksFor(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsAffiliation(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsMemberOf(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsAlumniOf(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsBirthPlace(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsDeathPlace(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsHomeLocation(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsResultsWorkLocation(BaseModel):
    id: str
    name: str


class QueryPersonsClustersPersonsClusters(BaseModel):
    clusters: Optional[list["QueryPersonsClustersPersonsClustersClusters"]]


class QueryPersonsClustersPersonsClustersClusters(BaseModel):
    entities: list["QueryPersonsClustersPersonsClustersClustersEntities"]
    similarity: Optional[float]


class QueryPersonsClustersPersonsClustersClustersEntities(BaseModel):
    id: str
    name: Optional[str]


QueryPersonsClusters.model_rebuild()
QueryPersonsClustersPersons.model_rebuild()
QueryPersonsClustersPersonsResults.model_rebuild()
QueryPersonsClustersPersonsClusters.model_rebuild()
QueryPersonsClustersPersonsClustersClusters.model_rebuild()
