# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryCategories(BaseModel):
    categories: Optional["QueryCategoriesCategories"]


class QueryCategoriesCategories(BaseModel):
    results: Optional[list[Optional["QueryCategoriesCategoriesResults"]]]


class QueryCategoriesCategoriesResults(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    feeds: Optional[list[Optional["QueryCategoriesCategoriesResultsFeeds"]]]


class QueryCategoriesCategoriesResultsFeeds(BaseModel):
    id: str
    name: str


QueryCategories.model_rebuild()
QueryCategoriesCategories.model_rebuild()
QueryCategoriesCategoriesResults.model_rebuild()
