# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class TriggerFeed(BaseModel):
    trigger_feed: Optional["TriggerFeedTriggerFeed"] = Field(alias="triggerFeed")


class TriggerFeedTriggerFeed(BaseModel):
    id: str
    state: EntityState


TriggerFeed.model_rebuild()
