# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ConversationTypes, EntityState


class BranchConversation(BaseModel):
    branch_conversation: Optional["BranchConversationBranchConversation"] = Field(
        alias="branchConversation"
    )


class BranchConversationBranchConversation(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ConversationTypes]


BranchConversation.model_rebuild()
