# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityTypes


class QueryConversationsGraph(BaseModel):
    conversations: Optional["QueryConversationsGraphConversations"]


class QueryConversationsGraphConversations(BaseModel):
    graph: Optional["QueryConversationsGraphConversationsGraph"]


class QueryConversationsGraphConversationsGraph(BaseModel):
    nodes: Optional[list[Optional["QueryConversationsGraphConversationsGraphNodes"]]]
    edges: Optional[list[Optional["QueryConversationsGraphConversationsGraphEdges"]]]


class QueryConversationsGraphConversationsGraphNodes(BaseModel):
    id: str
    name: str
    type: EntityTypes
    metadata: Optional[str]


class QueryConversationsGraphConversationsGraphEdges(BaseModel):
    from_: str = Field(alias="from")
    to: str
    relation: Optional[str]


QueryConversationsGraph.model_rebuild()
QueryConversationsGraphConversations.model_rebuild()
QueryConversationsGraphConversationsGraph.model_rebuild()
