# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalDevice(BaseModel):
    create_medical_device: Optional["CreateMedicalDeviceCreateMedicalDevice"] = Field(
        alias="createMedicalDevice"
    )


class CreateMedicalDeviceCreateMedicalDevice(BaseModel):
    id: str
    name: str


CreateMedicalDevice.model_rebuild()
