# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ObservableTypes


class ResolveEntity(BaseModel):
    resolve_entity: Optional["ResolveEntityResolveEntity"] = Field(
        alias="resolveEntity"
    )


class ResolveEntityResolveEntity(BaseModel):
    reference: Optional["ResolveEntityResolveEntityReference"]
    relevance: Optional[float]
    reasoning: Optional[str]


class ResolveEntityResolveEntityReference(BaseModel):
    type: ObservableTypes
    observable: "ResolveEntityResolveEntityReferenceObservable"


class ResolveEntityResolveEntityReferenceObservable(BaseModel):
    id: str
    name: Optional[str]


ResolveEntity.model_rebuild()
ResolveEntityResolveEntity.model_rebuild()
ResolveEntityResolveEntityReference.model_rebuild()
