# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountAgents(BaseModel):
    count_agents: Optional["CountAgentsCountAgents"] = Field(alias="countAgents")


class CountAgentsCountAgents(BaseModel):
    count: Optional[Any]


CountAgents.model_rebuild()
