# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryAsanaProjects(BaseModel):
    asana_projects: Optional["QueryAsanaProjectsAsanaProjects"] = Field(
        alias="asanaProjects"
    )


class QueryAsanaProjectsAsanaProjects(BaseModel):
    results: Optional[list[str]]


QueryAsanaProjects.model_rebuild()
