# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalTherapies(BaseModel):
    delete_medical_therapies: Optional[
        list[Optional["DeleteMedicalTherapiesDeleteMedicalTherapies"]]
    ] = Field(alias="deleteMedicalTherapies")


class DeleteMedicalTherapiesDeleteMedicalTherapies(BaseModel):
    id: str
    state: EntityState


DeleteMedicalTherapies.model_rebuild()
