# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class RemoveContentLabel(BaseModel):
    remove_content_label: Optional["RemoveContentLabelRemoveContentLabel"] = Field(
        alias="removeContentLabel"
    )


class RemoveContentLabelRemoveContentLabel(BaseModel):
    id: str
    name: str


RemoveContentLabel.model_rebuild()
