# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteCategories(BaseModel):
    delete_categories: Optional[list[Optional["DeleteCategoriesDeleteCategories"]]] = (
        Field(alias="deleteCategories")
    )


class DeleteCategoriesDeleteCategories(BaseModel):
    id: str
    state: EntityState


DeleteCategories.model_rebuild()
