# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllMedicalIndications(BaseModel):
    delete_all_medical_indications: Optional[
        list[Optional["DeleteAllMedicalIndicationsDeleteAllMedicalIndications"]]
    ] = Field(alias="deleteAllMedicalIndications")


class DeleteAllMedicalIndicationsDeleteAllMedicalIndications(BaseModel):
    id: str
    state: EntityState


DeleteAllMedicalIndications.model_rebuild()
