# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllMedicalDrugClasses(BaseModel):
    delete_all_medical_drug_classes: Optional[
        list[Optional["DeleteAllMedicalDrugClassesDeleteAllMedicalDrugClasses"]]
    ] = Field(alias="deleteAllMedicalDrugClasses")


class DeleteAllMedicalDrugClassesDeleteAllMedicalDrugClasses(BaseModel):
    id: str
    state: EntityState


DeleteAllMedicalDrugClasses.model_rebuild()
