# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import AgentTypes, EntityState


class UpsertAgent(BaseModel):
    upsert_agent: Optional["UpsertAgentUpsertAgent"] = Field(alias="upsertAgent")


class UpsertAgentUpsertAgent(BaseModel):
    id: str
    name: str
    state: EntityState
    type: AgentTypes


UpsertAgent.model_rebuild()
