# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAgents(BaseModel):
    delete_agents: Optional[list[Optional["DeleteAgentsDeleteAgents"]]] = Field(
        alias="deleteAgents"
    )


class DeleteAgentsDeleteAgents(BaseModel):
    id: str
    state: EntityState


DeleteAgents.model_rebuild()
