# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalDrugs(BaseModel):
    count_medical_drugs: Optional["CountMedicalDrugsCountMedicalDrugs"] = Field(
        alias="countMedicalDrugs"
    )


class CountMedicalDrugsCountMedicalDrugs(BaseModel):
    count: Optional[Any]


CountMedicalDrugs.model_rebuild()
