# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import AlertTypes, EntityState


class CreateAlert(BaseModel):
    create_alert: Optional["CreateAlertCreateAlert"] = Field(alias="createAlert")


class CreateAlertCreateAlert(BaseModel):
    id: str
    name: str
    state: EntityState
    type: AlertTypes


CreateAlert.model_rebuild()
