# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBambooHRDepartments(BaseModel):
    bamboo_hr_departments: Optional["QueryBambooHRDepartmentsBambooHrDepartments"] = (
        Field(alias="bambooHRDepartments")
    )


class QueryBambooHRDepartmentsBambooHrDepartments(BaseModel):
    results: Optional[
        list[Optional["QueryBambooHRDepartmentsBambooHrDepartmentsResults"]]
    ]


class QueryBambooHRDepartmentsBambooHrDepartmentsResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryBambooHRDepartments.model_rebuild()
QueryBambooHRDepartmentsBambooHrDepartments.model_rebuild()
