# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import AgentTypes, EntityState


class UpdateAgent(BaseModel):
    update_agent: Optional["UpdateAgentUpdateAgent"] = Field(alias="updateAgent")


class UpdateAgentUpdateAgent(BaseModel):
    id: str
    name: str
    state: EntityState
    type: AgentTypes


UpdateAgent.model_rebuild()
