# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllPlaces(BaseModel):
    delete_all_places: Optional[list[Optional["DeleteAllPlacesDeleteAllPlaces"]]] = (
        Field(alias="deleteAllPlaces")
    )


class DeleteAllPlacesDeleteAllPlaces(BaseModel):
    id: str
    state: EntityState


DeleteAllPlaces.model_rebuild()
