# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllInvestments(BaseModel):
    delete_all_investments: Optional[
        list[Optional["DeleteAllInvestmentsDeleteAllInvestments"]]
    ] = Field(alias="deleteAllInvestments")


class DeleteAllInvestmentsDeleteAllInvestments(BaseModel):
    id: str
    state: EntityState


DeleteAllInvestments.model_rebuild()
