# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGustoCompanies(BaseModel):
    gusto_companies: Optional["QueryGustoCompaniesGustoCompanies"] = Field(
        alias="gustoCompanies"
    )


class QueryGustoCompaniesGustoCompanies(BaseModel):
    results: Optional[list[Optional["QueryGustoCompaniesGustoCompaniesResults"]]]


class QueryGustoCompaniesGustoCompaniesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]
    ein: Optional[str]


QueryGustoCompanies.model_rebuild()
QueryGustoCompaniesGustoCompanies.model_rebuild()
