# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class CreateFact(BaseModel):
    create_fact: Optional["CreateFactCreateFact"] = Field(alias="createFact")


class CreateFactCreateFact(BaseModel):
    id: str
    state: EntityState


CreateFact.model_rebuild()
