# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountFacts(BaseModel):
    count_facts: Optional["CountFactsCountFacts"] = Field(alias="countFacts")


class CountFactsCountFacts(BaseModel):
    count: Optional[Any]


CountFacts.model_rebuild()
