# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class UpdateFact(BaseModel):
    update_fact: Optional["UpdateFactUpdateFact"] = Field(alias="updateFact")


class UpdateFactUpdateFact(BaseModel):
    id: str
    state: EntityState


UpdateFact.model_rebuild()
