# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllSkills(BaseModel):
    delete_all_skills: Optional[list[Optional["DeleteAllSkillsDeleteAllSkills"]]] = (
        Field(alias="deleteAllSkills")
    )


class DeleteAllSkillsDeleteAllSkills(BaseModel):
    id: str
    state: EntityState


DeleteAllSkills.model_rebuild()
