# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class EnableAgent(BaseModel):
    enable_agent: Optional["EnableAgentEnableAgent"] = Field(alias="enableAgent")


class EnableAgentEnableAgent(BaseModel):
    id: str
    state: EntityState


EnableAgent.model_rebuild()
