# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryAsanaWorkspaces(BaseModel):
    asana_workspaces: Optional["QueryAsanaWorkspacesAsanaWorkspaces"] = Field(
        alias="asanaWorkspaces"
    )


class QueryAsanaWorkspacesAsanaWorkspaces(BaseModel):
    results: Optional[list[str]]


QueryAsanaWorkspaces.model_rebuild()
