# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSpecifications(BaseModel):
    delete_specifications: Optional[
        list[Optional["DeleteSpecificationsDeleteSpecifications"]]
    ] = Field(alias="deleteSpecifications")


class DeleteSpecificationsDeleteSpecifications(BaseModel):
    id: str
    state: EntityState


DeleteSpecifications.model_rebuild()
