# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAgent(BaseModel):
    delete_agent: Optional["DeleteAgentDeleteAgent"] = Field(alias="deleteAgent")


class DeleteAgentDeleteAgent(BaseModel):
    id: str
    state: EntityState


DeleteAgent.model_rebuild()
