# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class AddSkillsToCollections(BaseModel):
    add_skills_to_collections: Optional[
        list[Optional["AddSkillsToCollectionsAddSkillsToCollections"]]
    ] = Field(alias="addSkillsToCollections")


class AddSkillsToCollectionsAddSkillsToCollections(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[Optional["AddSkillsToCollectionsAddSkillsToCollectionsContents"]]
    ]


class AddSkillsToCollectionsAddSkillsToCollectionsContents(BaseModel):
    id: str
    name: str


AddSkillsToCollections.model_rebuild()
AddSkillsToCollectionsAddSkillsToCollections.model_rebuild()
