# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSkills(BaseModel):
    delete_skills: Optional[list[Optional["DeleteSkillsDeleteSkills"]]] = Field(
        alias="deleteSkills"
    )


class DeleteSkillsDeleteSkills(BaseModel):
    id: str
    state: EntityState


DeleteSkills.model_rebuild()
