# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateInvestmentFund(BaseModel):
    create_investment_fund: Optional["CreateInvestmentFundCreateInvestmentFund"] = (
        Field(alias="createInvestmentFund")
    )


class CreateInvestmentFundCreateInvestmentFund(BaseModel):
    id: str
    name: str


CreateInvestmentFund.model_rebuild()
