# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllAlerts(BaseModel):
    delete_all_alerts: Optional[list[Optional["DeleteAllAlertsDeleteAllAlerts"]]] = (
        Field(alias="deleteAllAlerts")
    )


class DeleteAllAlertsDeleteAllAlerts(BaseModel):
    id: str
    state: EntityState


DeleteAllAlerts.model_rebuild()
