# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountPersonas(BaseModel):
    count_personas: Optional["CountPersonasCountPersonas"] = Field(
        alias="countPersonas"
    )


class CountPersonasCountPersonas(BaseModel):
    count: Optional[Any]


CountPersonas.model_rebuild()
