# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class GetMedicalStudy(BaseModel):
    medical_study: Optional["GetMedicalStudyMedicalStudy"] = Field(alias="medicalStudy")


class GetMedicalStudyMedicalStudy(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetMedicalStudyMedicalStudyOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[list[Optional["GetMedicalStudyMedicalStudyFeeds"]]]
    links: Optional[list[Optional["GetMedicalStudyMedicalStudyLinks"]]]
    workflow: Optional["GetMedicalStudyMedicalStudyWorkflow"]
    location: Optional["GetMedicalStudyMedicalStudyLocation"]
    h_3: Optional["GetMedicalStudyMedicalStudyH3"] = Field(alias="h3")
    address: Optional["GetMedicalStudyMedicalStudyAddress"]


class GetMedicalStudyMedicalStudyOwner(BaseModel):
    id: str


class GetMedicalStudyMedicalStudyFeeds(BaseModel):
    id: str
    name: str


class GetMedicalStudyMedicalStudyLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class GetMedicalStudyMedicalStudyWorkflow(BaseModel):
    id: str
    name: str


class GetMedicalStudyMedicalStudyLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class GetMedicalStudyMedicalStudyH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class GetMedicalStudyMedicalStudyAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


GetMedicalStudy.model_rebuild()
GetMedicalStudyMedicalStudy.model_rebuild()
