# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountInvestments(BaseModel):
    count_investments: Optional["CountInvestmentsCountInvestments"] = Field(
        alias="countInvestments"
    )


class CountInvestmentsCountInvestments(BaseModel):
    count: Optional[Any]


CountInvestments.model_rebuild()
