# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllAgents(BaseModel):
    delete_all_agents: Optional[list[Optional["DeleteAllAgentsDeleteAllAgents"]]] = (
        Field(alias="deleteAllAgents")
    )


class DeleteAllAgentsDeleteAllAgents(BaseModel):
    id: str
    state: EntityState


DeleteAllAgents.model_rebuild()
