# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EnrichPlaces(BaseModel):
    enrich_places: Optional[list[Optional["EnrichPlacesEnrichPlaces"]]] = Field(
        alias="enrichPlaces"
    )


class EnrichPlacesEnrichPlaces(BaseModel):
    id: str
    name: str


EnrichPlaces.model_rebuild()
