# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateEmotion(BaseModel):
    create_emotion: Optional["CreateEmotionCreateEmotion"] = Field(
        alias="createEmotion"
    )


class CreateEmotionCreateEmotion(BaseModel):
    id: str
    name: str


CreateEmotion.model_rebuild()
