# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SuggestConversation(BaseModel):
    suggest_conversation: Optional["SuggestConversationSuggestConversation"] = Field(
        alias="suggestConversation"
    )


class SuggestConversationSuggestConversation(BaseModel):
    prompts: Optional[list[Optional[str]]]


SuggestConversation.model_rebuild()
