# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class UpdateJiraIssue(BaseModel):
    update_jira_issue: Optional["UpdateJiraIssueUpdateJiraIssue"] = Field(
        alias="updateJiraIssue"
    )


class UpdateJiraIssueUpdateJiraIssue(BaseModel):
    identifier: Optional[str]
    uri: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")


UpdateJiraIssue.model_rebuild()
