# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class EnableSkill(BaseModel):
    enable_skill: Optional["EnableSkillEnableSkill"] = Field(alias="enableSkill")


class EnableSkillEnableSkill(BaseModel):
    id: str
    state: EntityState


EnableSkill.model_rebuild()
