# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMondayBoards(BaseModel):
    monday_boards: Optional["QueryMondayBoardsMondayBoards"] = Field(
        alias="mondayBoards"
    )


class QueryMondayBoardsMondayBoards(BaseModel):
    results: Optional[list[str]]


QueryMondayBoards.model_rebuild()
