# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllEvents(BaseModel):
    delete_all_events: Optional[list[Optional["DeleteAllEventsDeleteAllEvents"]]] = (
        Field(alias="deleteAllEvents")
    )


class DeleteAllEventsDeleteAllEvents(BaseModel):
    id: str
    state: EntityState


DeleteAllEvents.model_rebuild()
