# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalConditions(BaseModel):
    delete_medical_conditions: Optional[
        list[Optional["DeleteMedicalConditionsDeleteMedicalConditions"]]
    ] = Field(alias="deleteMedicalConditions")


class DeleteMedicalConditionsDeleteMedicalConditions(BaseModel):
    id: str
    state: EntityState


DeleteMedicalConditions.model_rebuild()
