# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class RemoveContentsFromCollection(BaseModel):
    remove_contents_from_collection: Optional[
        "RemoveContentsFromCollectionRemoveContentsFromCollection"
    ] = Field(alias="removeContentsFromCollection")


class RemoveContentsFromCollectionRemoveContentsFromCollection(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[
            Optional["RemoveContentsFromCollectionRemoveContentsFromCollectionContents"]
        ]
    ]


class RemoveContentsFromCollectionRemoveContentsFromCollectionContents(BaseModel):
    id: str
    name: str


RemoveContentsFromCollection.model_rebuild()
RemoveContentsFromCollectionRemoveContentsFromCollection.model_rebuild()
