# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSkill(BaseModel):
    delete_skill: Optional["DeleteSkillDeleteSkill"] = Field(alias="deleteSkill")


class DeleteSkillDeleteSkill(BaseModel):
    id: str
    state: EntityState


DeleteSkill.model_rebuild()
