# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryConfluenceSpaces(BaseModel):
    confluence_spaces: Optional["QueryConfluenceSpacesConfluenceSpaces"] = Field(
        alias="confluenceSpaces"
    )


class QueryConfluenceSpacesConfluenceSpaces(BaseModel):
    results: Optional[list[Optional["QueryConfluenceSpacesConfluenceSpacesResults"]]]


class QueryConfluenceSpacesConfluenceSpacesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]
    key: Optional[str]


QueryConfluenceSpaces.model_rebuild()
QueryConfluenceSpacesConfluenceSpaces.model_rebuild()
