# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllRepos(BaseModel):
    delete_all_repos: Optional[list[Optional["DeleteAllReposDeleteAllRepos"]]] = Field(
        alias="deleteAllRepos"
    )


class DeleteAllReposDeleteAllRepos(BaseModel):
    id: str
    state: EntityState


DeleteAllRepos.model_rebuild()
