# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMicrosoftCalendarEvent(BaseModel):
    update_microsoft_calendar_event: Optional[
        "UpdateMicrosoftCalendarEventUpdateMicrosoftCalendarEvent"
    ] = Field(alias="updateMicrosoftCalendarEvent")


class UpdateMicrosoftCalendarEventUpdateMicrosoftCalendarEvent(BaseModel):
    event_id: str = Field(alias="eventId")
    summary: Optional[str]
    start_date_time: Any = Field(alias="startDateTime")
    end_date_time: Any = Field(alias="endDateTime")
    location: Optional[str]
    attendees: Optional[list[Optional[str]]]
    is_online_meeting: Optional[bool] = Field(alias="isOnlineMeeting")
    meeting_link: Optional[str] = Field(alias="meetingLink")
    description: Optional[str]
    status: Optional[str]
    organizer: Optional[str]


UpdateMicrosoftCalendarEvent.model_rebuild()
