# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class UpdateLinearIssue(BaseModel):
    update_linear_issue: Optional["UpdateLinearIssueUpdateLinearIssue"] = Field(
        alias="updateLinearIssue"
    )


class UpdateLinearIssueUpdateLinearIssue(BaseModel):
    identifier: Optional[str]
    uri: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")


UpdateLinearIssue.model_rebuild()
