# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class UpdateConfluencePage(BaseModel):
    update_confluence_page: Optional["UpdateConfluencePageUpdateConfluencePage"] = (
        Field(alias="updateConfluencePage")
    )


class UpdateConfluencePageUpdateConfluencePage(BaseModel):
    identifier: Optional[str]
    uri: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")


UpdateConfluencePage.model_rebuild()
