# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalContraindications(BaseModel):
    count_medical_contraindications: Optional[
        "CountMedicalContraindicationsCountMedicalContraindications"
    ] = Field(alias="countMedicalContraindications")


class CountMedicalContraindicationsCountMedicalContraindications(BaseModel):
    count: Optional[Any]


CountMedicalContraindications.model_rebuild()
