# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllFacts(BaseModel):
    delete_all_facts: Optional[list[Optional["DeleteAllFactsDeleteAllFacts"]]] = Field(
        alias="deleteAllFacts"
    )


class DeleteAllFactsDeleteAllFacts(BaseModel):
    id: str
    state: EntityState


DeleteAllFacts.model_rebuild()
