# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class GetPersona(BaseModel):
    persona: Optional["GetPersonaPersona"]


class GetPersonaPersona(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetPersonaPersonaOwner"
    state: EntityState
    identifier: Optional[str]
    platform: Optional[str]
    display_name: Optional[str] = Field(alias="displayName")
    timezone: Optional[str]
    role: Optional[str]
    instructions: Optional[str]
    facts: Optional[list["GetPersonaPersonaFacts"]]


class GetPersonaPersonaOwner(BaseModel):
    id: str


class GetPersonaPersonaFacts(BaseModel):
    id: Optional[str]
    text: Optional[str]


GetPersona.model_rebuild()
GetPersonaPersona.model_rebuild()
