# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryMedicalDrugsClusters(BaseModel):
    medical_drugs: Optional["QueryMedicalDrugsClustersMedicalDrugs"] = Field(
        alias="medicalDrugs"
    )


class QueryMedicalDrugsClustersMedicalDrugs(BaseModel):
    results: Optional[list[Optional["QueryMedicalDrugsClustersMedicalDrugsResults"]]]
    clusters: Optional["QueryMedicalDrugsClustersMedicalDrugsClusters"]


class QueryMedicalDrugsClustersMedicalDrugsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryMedicalDrugsClustersMedicalDrugsResultsOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[list[Optional["QueryMedicalDrugsClustersMedicalDrugsResultsFeeds"]]]
    links: Optional[list[Optional["QueryMedicalDrugsClustersMedicalDrugsResultsLinks"]]]
    workflow: Optional["QueryMedicalDrugsClustersMedicalDrugsResultsWorkflow"]
    location: Optional["QueryMedicalDrugsClustersMedicalDrugsResultsLocation"]
    h_3: Optional["QueryMedicalDrugsClustersMedicalDrugsResultsH3"] = Field(alias="h3")


class QueryMedicalDrugsClustersMedicalDrugsResultsOwner(BaseModel):
    id: str


class QueryMedicalDrugsClustersMedicalDrugsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryMedicalDrugsClustersMedicalDrugsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryMedicalDrugsClustersMedicalDrugsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryMedicalDrugsClustersMedicalDrugsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryMedicalDrugsClustersMedicalDrugsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryMedicalDrugsClustersMedicalDrugsClusters(BaseModel):
    clusters: Optional[list["QueryMedicalDrugsClustersMedicalDrugsClustersClusters"]]


class QueryMedicalDrugsClustersMedicalDrugsClustersClusters(BaseModel):
    entities: list["QueryMedicalDrugsClustersMedicalDrugsClustersClustersEntities"]
    similarity: Optional[float]


class QueryMedicalDrugsClustersMedicalDrugsClustersClustersEntities(BaseModel):
    id: str
    name: Optional[str]


QueryMedicalDrugsClusters.model_rebuild()
QueryMedicalDrugsClustersMedicalDrugs.model_rebuild()
QueryMedicalDrugsClustersMedicalDrugsResults.model_rebuild()
QueryMedicalDrugsClustersMedicalDrugsClusters.model_rebuild()
QueryMedicalDrugsClustersMedicalDrugsClustersClusters.model_rebuild()
