# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteFact(BaseModel):
    delete_fact: Optional["DeleteFactDeleteFact"] = Field(alias="deleteFact")


class DeleteFactDeleteFact(BaseModel):
    id: str
    state: EntityState


DeleteFact.model_rebuild()
