# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePlaces(BaseModel):
    delete_places: Optional[list[Optional["DeletePlacesDeletePlaces"]]] = Field(
        alias="deletePlaces"
    )


class DeletePlacesDeletePlaces(BaseModel):
    id: str
    state: EntityState


DeletePlaces.model_rebuild()
