# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePersona(BaseModel):
    delete_persona: Optional["DeletePersonaDeletePersona"] = Field(
        alias="deletePersona"
    )


class DeletePersonaDeletePersona(BaseModel):
    id: str
    state: EntityState


DeletePersona.model_rebuild()
