# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class LookupCompanies(BaseModel):
    lookup_companies: Optional["LookupCompaniesLookupCompanies"] = Field(
        alias="lookupCompanies"
    )


class LookupCompaniesLookupCompanies(BaseModel):
    results: Optional[list[Optional["LookupCompaniesLookupCompaniesResults"]]]


class LookupCompaniesLookupCompaniesResults(BaseModel):
    company_id: Optional[str] = Field(alias="companyId")
    company_name: Optional[str] = Field(alias="companyName")
    company_domain: Optional[str] = Field(alias="companyDomain")
    company_linked_in_url: Optional[Any] = Field(alias="companyLinkedInUrl")
    headquarters: Optional[str]
    hq_country: Optional[str] = Field(alias="hqCountry")
    headcount: Optional[int]
    employee_count_range: Optional[str] = Field(alias="employeeCountRange")
    industries: Optional[list[Optional[str]]]
    estimated_revenue_lower_bound: Optional[Any] = Field(
        alias="estimatedRevenueLowerBound"
    )
    estimated_revenue_upper_bound: Optional[Any] = Field(
        alias="estimatedRevenueUpperBound"
    )
    logo_url: Optional[Any] = Field(alias="logoUrl")


LookupCompanies.model_rebuild()
LookupCompaniesLookupCompanies.model_rebuild()
