# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class AddContentLabel(BaseModel):
    add_content_label: Optional["AddContentLabelAddContentLabel"] = Field(
        alias="addContentLabel"
    )


class AddContentLabelAddContentLabel(BaseModel):
    id: str
    name: str


AddContentLabel.model_rebuild()
