# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class DeleteGoogleCalendarEvent(BaseModel):
    delete_google_calendar_event: Optional[bool] = Field(
        alias="deleteGoogleCalendarEvent"
    )
