# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ObservableTypes


class RetrieveEntities(BaseModel):
    retrieve_entities: Optional["RetrieveEntitiesRetrieveEntities"] = Field(
        alias="retrieveEntities"
    )


class RetrieveEntitiesRetrieveEntities(BaseModel):
    results: Optional[list[Optional["RetrieveEntitiesRetrieveEntitiesResults"]]]


class RetrieveEntitiesRetrieveEntitiesResults(BaseModel):
    id: str
    name: Optional[str]
    type: ObservableTypes
    relevance: Optional[float]
    metadata: Optional[str]


RetrieveEntities.model_rebuild()
RetrieveEntitiesRetrieveEntities.model_rebuild()
