# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEmotion(BaseModel):
    emotion: Optional["GetEmotionEmotion"]


class GetEmotionEmotion(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    feeds: Optional[list[Optional["GetEmotionEmotionFeeds"]]]


class GetEmotionEmotionFeeds(BaseModel):
    id: str
    name: str


GetEmotion.model_rebuild()
GetEmotionEmotion.model_rebuild()
