# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGustoDepartments(BaseModel):
    gusto_departments: Optional["QueryGustoDepartmentsGustoDepartments"] = Field(
        alias="gustoDepartments"
    )


class QueryGustoDepartmentsGustoDepartments(BaseModel):
    results: Optional[list[Optional["QueryGustoDepartmentsGustoDepartmentsResults"]]]


class QueryGustoDepartmentsGustoDepartmentsResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryGustoDepartments.model_rebuild()
QueryGustoDepartmentsGustoDepartments.model_rebuild()
