# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateEmotion(BaseModel):
    update_emotion: Optional["UpdateEmotionUpdateEmotion"] = Field(
        alias="updateEmotion"
    )


class UpdateEmotionUpdateEmotion(BaseModel):
    id: str
    name: str


UpdateEmotion.model_rebuild()
