# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityOwners, EntityState


class UpsertSkill(BaseModel):
    upsert_skill: Optional["UpsertSkillUpsertSkill"] = Field(alias="upsertSkill")


class UpsertSkillUpsertSkill(BaseModel):
    id: str
    name: str
    state: EntityState
    identifier: Optional[str]
    skill_owner: Optional[EntityOwners] = Field(alias="skillOwner")
    arguments: Optional[list["UpsertSkillUpsertSkillArguments"]]


class UpsertSkillUpsertSkillArguments(BaseModel):
    name: str
    description: Optional[str]
    required: Optional[bool]


UpsertSkill.model_rebuild()
UpsertSkillUpsertSkill.model_rebuild()
