# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBambooHRDivisions(BaseModel):
    bamboo_hr_divisions: Optional["QueryBambooHRDivisionsBambooHrDivisions"] = Field(
        alias="bambooHRDivisions"
    )


class QueryBambooHRDivisionsBambooHrDivisions(BaseModel):
    results: Optional[list[Optional["QueryBambooHRDivisionsBambooHrDivisionsResults"]]]


class QueryBambooHRDivisionsBambooHrDivisionsResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryBambooHRDivisions.model_rebuild()
QueryBambooHRDivisionsBambooHrDivisions.model_rebuild()
