# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryAtlassianSites(BaseModel):
    atlassian_sites: Optional["QueryAtlassianSitesAtlassianSites"] = Field(
        alias="atlassianSites"
    )


class QueryAtlassianSitesAtlassianSites(BaseModel):
    results: Optional[list[Optional["QueryAtlassianSitesAtlassianSitesResults"]]]


class QueryAtlassianSitesAtlassianSitesResults(BaseModel):
    identifier: Optional[str]
    name: Optional[str]
    url: Optional[str]


QueryAtlassianSites.model_rebuild()
QueryAtlassianSitesAtlassianSites.model_rebuild()
