# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGustoLocations(BaseModel):
    gusto_locations: Optional["QueryGustoLocationsGustoLocations"] = Field(
        alias="gustoLocations"
    )


class QueryGustoLocationsGustoLocations(BaseModel):
    results: Optional[list[Optional["QueryGustoLocationsGustoLocationsResults"]]]


class QueryGustoLocationsGustoLocationsResults(BaseModel):
    identifier: Optional[str]
    street_1: Optional[str] = Field(alias="street1")
    street_2: Optional[str] = Field(alias="street2")
    city: Optional[str]
    state: Optional[str]
    zip: Optional[str]
    country: Optional[str]


QueryGustoLocations.model_rebuild()
QueryGustoLocationsGustoLocations.model_rebuild()
