# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class UpdateNotionPage(BaseModel):
    update_notion_page: Optional["UpdateNotionPageUpdateNotionPage"] = Field(
        alias="updateNotionPage"
    )


class UpdateNotionPageUpdateNotionPage(BaseModel):
    identifier: Optional[str]
    uri: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")


UpdateNotionPage.model_rebuild()
