# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBambooHRLocations(BaseModel):
    bamboo_hr_locations: Optional["QueryBambooHRLocationsBambooHrLocations"] = Field(
        alias="bambooHRLocations"
    )


class QueryBambooHRLocationsBambooHrLocations(BaseModel):
    results: Optional[list[Optional["QueryBambooHRLocationsBambooHrLocationsResults"]]]


class QueryBambooHRLocationsBambooHrLocationsResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryBambooHRLocations.model_rebuild()
QueryBambooHRLocationsBambooHrLocations.model_rebuild()
