# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteFeeds(BaseModel):
    delete_feeds: Optional[list[Optional["DeleteFeedsDeleteFeeds"]]] = Field(
        alias="deleteFeeds"
    )


class DeleteFeedsDeleteFeeds(BaseModel):
    id: str
    state: EntityState


DeleteFeeds.model_rebuild()
