# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class DistributeContents(BaseModel):
    distribute_contents: Optional[list["DistributeContentsDistributeContents"]] = Field(
        alias="distributeContents"
    )


class DistributeContentsDistributeContents(BaseModel):
    uri: Optional[str]
    identifier: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")
    error: Optional[str]


DistributeContents.model_rebuild()
