# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBambooHREmploymentStatuses(BaseModel):
    bamboo_hr_employment_statuses: Optional[
        "QueryBambooHREmploymentStatusesBambooHrEmploymentStatuses"
    ] = Field(alias="bambooHREmploymentStatuses")


class QueryBambooHREmploymentStatusesBambooHrEmploymentStatuses(BaseModel):
    results: Optional[
        list[
            Optional["QueryBambooHREmploymentStatusesBambooHrEmploymentStatusesResults"]
        ]
    ]


class QueryBambooHREmploymentStatusesBambooHrEmploymentStatusesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryBambooHREmploymentStatuses.model_rebuild()
QueryBambooHREmploymentStatusesBambooHrEmploymentStatuses.model_rebuild()
