# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class Distribute(BaseModel):
    distribute: Optional[list["DistributeDistribute"]]


class DistributeDistribute(BaseModel):
    uri: Optional[str]
    identifier: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")
    error: Optional[str]


Distribute.model_rebuild()
