# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteEmotion(BaseModel):
    delete_emotion: Optional["DeleteEmotionDeleteEmotion"] = Field(
        alias="deleteEmotion"
    )


class DeleteEmotionDeleteEmotion(BaseModel):
    id: str
    state: EntityState


DeleteEmotion.model_rebuild()
