# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class RemoveConversationsFromCollection(BaseModel):
    remove_conversations_from_collection: Optional[
        "RemoveConversationsFromCollectionRemoveConversationsFromCollection"
    ] = Field(alias="removeConversationsFromCollection")


class RemoveConversationsFromCollectionRemoveConversationsFromCollection(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[
            Optional[
                "RemoveConversationsFromCollectionRemoveConversationsFromCollectionContents"
            ]
        ]
    ]


class RemoveConversationsFromCollectionRemoveConversationsFromCollectionContents(
    BaseModel
):
    id: str
    name: str


RemoveConversationsFromCollection.model_rebuild()
RemoveConversationsFromCollectionRemoveConversationsFromCollection.model_rebuild()
