# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGoogleDriveDrives(BaseModel):
    google_drive_drives: Optional["QueryGoogleDriveDrivesGoogleDriveDrives"] = Field(
        alias="googleDriveDrives"
    )


class QueryGoogleDriveDrivesGoogleDriveDrives(BaseModel):
    results: Optional[list[Optional["QueryGoogleDriveDrivesGoogleDriveDrivesResults"]]]


class QueryGoogleDriveDrivesGoogleDriveDrivesResults(BaseModel):
    drive_id: Optional[str] = Field(alias="driveId")
    drive_name: Optional[str] = Field(alias="driveName")


QueryGoogleDriveDrives.model_rebuild()
QueryGoogleDriveDrivesGoogleDriveDrives.model_rebuild()
