# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateLabel(BaseModel):
    update_label: Optional["UpdateLabelUpdateLabel"] = Field(alias="updateLabel")


class UpdateLabelUpdateLabel(BaseModel):
    id: str
    name: str


UpdateLabel.model_rebuild()
