# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class ApproveContent(BaseModel):
    approve_content: Optional["ApproveContentApproveContent"] = Field(
        alias="approveContent"
    )


class ApproveContentApproveContent(BaseModel):
    id: str
    state: EntityState


ApproveContent.model_rebuild()
