# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QuerySlackUsers(BaseModel):
    slack_users: Optional["QuerySlackUsersSlackUsers"] = Field(alias="slackUsers")


class QuerySlackUsersSlackUsers(BaseModel):
    results: Optional[list[Optional["QuerySlackUsersSlackUsersResults"]]]


class QuerySlackUsersSlackUsersResults(BaseModel):
    user_id: str = Field(alias="userId")
    display_name: str = Field(alias="displayName")
    real_name: Optional[str] = Field(alias="realName")
    email: Optional[str]


QuerySlackUsers.model_rebuild()
QuerySlackUsersSlackUsers.model_rebuild()
