# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DisableAgent(BaseModel):
    disable_agent: Optional["DisableAgentDisableAgent"] = Field(alias="disableAgent")


class DisableAgentDisableAgent(BaseModel):
    id: str
    state: EntityState


DisableAgent.model_rebuild()
