# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class LookupPersons(BaseModel):
    lookup_persons: Optional["LookupPersonsLookupPersons"] = Field(
        alias="lookupPersons"
    )


class LookupPersonsLookupPersons(BaseModel):
    results: Optional[list[Optional["LookupPersonsLookupPersonsResults"]]]


class LookupPersonsLookupPersonsResults(BaseModel):
    name: Optional[str]
    title: Optional[str]
    headline: Optional[str]
    location: Optional[str]
    linked_in_url: Optional[Any] = Field(alias="linkedInUrl")
    email: Optional[str]
    profile_picture_url: Optional[Any] = Field(alias="profilePictureUrl")
    current_company: Optional[str] = Field(alias="currentCompany")
    current_title: Optional[str] = Field(alias="currentTitle")
    skills: Optional[list[Optional[str]]]
    years_of_experience: Optional[float] = Field(alias="yearsOfExperience")


LookupPersons.model_rebuild()
LookupPersonsLookupPersons.model_rebuild()
