# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class MapWeb(BaseModel):
    map_web: Optional["MapWebMapWeb"] = Field(alias="mapWeb")


class MapWebMapWeb(BaseModel):
    results: Optional[list[Optional[Any]]]


MapWeb.model_rebuild()
